@@ -6,8 +6,7 @@
  *                  Volker Sameske,  <sameske@de.ibm.com>
  *                  Holger Smolinski,<smolinsk@de.ibm.com>
  *                  Gerhard Tonn     <ton@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 1999-2004
+ * Copyright IBM Corp. 1999,2007
  */
 
 #include <sys/utsname.h>
@@ -18,10 +17,10 @@
 #include "vtoc.h" 
 
 /* Full tool name */
-static const char tool_name[] = "zSeries DASD format program";
+static const char tool_name[] = "dasdfmt: zSeries DASD format program";
 
 /* Copyright notice */
-static const char copyright_notice[] = "(C) Copyright IBM Corp. 1999-2004";
+static const char copyright_notice[] = "Copyright IBM Corp. 1999, 2006";
 
 /*
  * Print version information.
@@ -69,9 +68,7 @@ static void exit_usage(int exitcode)
 	       "           and alternatively\n"
 	       "           -n xxxx or --devno=xxxx\n"
 	       "           in case you are using devfs.\n"
-	       "           xxxx is your hexadecimal device number.\n"
-	       "\n"
-	       "Please report bugs to: linux390@de.ibm.com\n");
+	       "           xxxx is your hexadecimal device number.\n");
 	exit(exitcode);
 }
 
@@ -797,9 +794,6 @@ int main(int argc,char *argv[])
 
 	/*************** parse parameters **********************/
 
-	/* avoid error message generated by getopt */
-	opterr=0;
-
 	while (1)
 	{
 		rc=getopt_long(argc, argv, dasdfmt_getopt_string,
@@ -861,7 +855,6 @@ int main(int argc,char *argv[])
 			info.verbosity=1;
 			break;
 
-		case '?': /* fall-through */
 		case 'h':
 			exit_usage(0);
 
@@ -909,6 +902,10 @@ int main(int argc,char *argv[])
 			/* End of options string - start of devices list */
 			info.device_id = optind;
 			break;
+		default:
+			ERRMSG_EXIT(EXIT_MISUSE,
+				"Try '%s --help' for more"
+				" information.\n",prog_name);
 		}
         	if (rc==-1) break; // exit loop if finished
 	}
