@@ -2,8 +2,7 @@
  * File...........: s390-tools/dasdfmt/dasdfmt.h
  * Author(s)......: Horst Hummel <Horst.Hummel@de.ibm.com>
  *                  Volker Sameske <sameske@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2002
+ * Copyright IBM Corp. 2002,2007
  */
 
 #ifndef DASDFMT_H
@@ -148,7 +147,7 @@ struct hd_geometry {
 	if (*endptr) ERRMSG_EXIT(EXIT_MISUSE,"%s: " str " "    \
 	"is in invalid format\n",prog_name);}
 
-#define dasdfmt_getopt_string "b:n:l:f:d:m:hpLty?vVFk"
+#define dasdfmt_getopt_string "b:n:l:f:d:m:hpLtyvVFk"
 
 static struct option dasdfmt_getopt_long_options[]=
 {
@@ -163,7 +162,7 @@ static struct option dasdfmt_getopt_long_options[]=
         { "devno",       1, 0, 'n'},
         { "device",      1, 0, 'f'},
         { "blocksize",   1, 0, 'b'},
-        { "help",        0, 0, '?'},
+        { "help",        0, 0, 'h'},
         { "keep_volser", 0, 0, 'k'},
         {0, 0, 0, 0}
 };
