@@ -2,8 +2,7 @@
  * File...........: s390-tools/dasdview/dasdview.c
  * Author(s)......: Volker Sameske <sameske@de.ibm.com>
  *                  Gerhard Tonn   <ton@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2001-2004
+ * Copyright IBM Corp. 2001, 2006.
  */
 
 #define _LARGEFILE64_SOURCE    /* needed for unistd.h */
@@ -16,6 +15,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <getopt.h>
+#include <stdarg.h>
 
 #include <sys/stat.h>
 #include <sys/ioctl.h>
@@ -23,12 +23,7 @@
 #include <sys/utsname.h>
 #include <linux/version.h>
 
-#ifdef SYSFS
-#include <sysfs/libsysfs.h>
-#endif
-
 #include "zt_common.h"
-#include "zt_error.h"
 #include "vtoc.h"
 #include "dasdview.h"
 #include "u2s.h"
@@ -37,10 +32,30 @@
 #define DASDVIEW_CPL 16
 
 /* Full tool name */
-static const char tool_name[] = "zSeries DASD view program";
+static const char tool_name[] = "dasdview: zSeries DASD view program";
 
 /* Copyright notice */
-static const char copyright_notice[] = "(C) Copyright IBM Corp. 2001-2004";
+static const char copyright_notice[] = "Copyright IBM Corp. 2001, 2006";
+
+/* Error message string */
+#define ERROR_STRING_SIZE       1024
+static char error_string[ERROR_STRING_SIZE];
+
+/*
+ * Generate and print an error message based on the formatted
+ * text string FMT and a variable amount of extra arguments.
+ */
+void
+zt_error_print (const char* fmt, ...)
+{
+	va_list args;
+
+	va_start (args, fmt);
+	vsnprintf (error_string, ERROR_STRING_SIZE, fmt, args);
+	va_end (args);
+
+	fprintf (stderr, "Error: %s\n", error_string);
+}
 
 /*
  * Print version information.
@@ -59,7 +74,7 @@ dasdview_usage(void)
 	printf("dasdview [-b begin] [-s size] [-1|-2] \n"
 	       "         [-i] [-x] [-j]\n"
 	       "         [-l] [-t {info|f1|f4|f5|f7|all}] \n"
-	       "         [-h] [-?] [-v] \n"
+	       "         [-h] [-v] \n"
 	       "         {-n devno|-f node}\n"
 	       "\nwhere:\n"
 	       "-b: prints a DASD dump from 'begin'\n"
@@ -76,12 +91,9 @@ dasdview_usage(void)
 	       "-l: prints information about the volume label\n"
 	       "-t: prints the table of content (VTOC)\n"
 	       "-h: prints this usage text\n"
-	       "-?: prints this usage text\n"
 	       "-v: prints the version number\n"
 	       "-n: specifies the device by a device number (needs devfs)\n"
-	       "-f: specifies a device by a device node\n"
-	       "\n"
-	       "Please report bugs to: linux390@de.ibm.com\n");
+	       "-f: specifies a device by a device node\n");
 }
 
 
@@ -136,10 +148,10 @@ dasdview_error(enum dasdview_failure why)
  * replace special characters with dots and question marks
  */
 static void
-dot (unsigned char label[16]) {
+dot (char label[]) {
 
         int i;
-	unsigned char c;
+	char c;
 
   	for (i = 0; i < 16; i++) {
 
@@ -256,7 +268,7 @@ dasdview_print_general_info(dasdview_info_t *info)
 	unsigned char a,b,c;
 	char suffix[sizeof(buf.release)];
 	int rc;
-	char busid[SYSFS_BUS_ID_SIZE];
+	char busid[U2S_BUS_ID_SIZE];
 
 	rc = uname(&buf);
 	if(!rc)
@@ -1333,7 +1345,6 @@ int main(int argc, char * argv[]) {
 	char *endptr          = NULL;
 
 	bzero (&info, sizeof(info));
-	opterr=0;
 	while (1)
 	{
 		oc = getopt_long(argc, argv, dasdview_getopt_string,
@@ -1341,7 +1352,6 @@ int main(int argc, char * argv[]) {
 
 		switch (oc)
 		{
-		case '?':
 		case 'h':
 			dasdview_usage();
 			exit(0);
@@ -1421,8 +1431,9 @@ int main(int argc, char * argv[]) {
 			info.device_id = optind;
 			break;
 		default:
-			dasdview_usage();
-			exit(0);
+			fprintf(stderr, "Try 'dasdview --help' for more"
+					" information.\n");
+			exit(1);
 		}
         	if (oc==-1) break;
 	}
