@@ -1,8 +1,7 @@
 /*
  * File...........: s390-tools/dasdview/dasdview.h
  * Author(s)......: Horst Hummel <horst.hummel@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2002
+ * Copyright IBM Corp. 2002, 2006.
  */
 
 #ifndef DASDVIEW_H
@@ -194,7 +193,7 @@ typedef struct dasdview_info
 } dasdview_info_t;
 
 
-#define dasdview_getopt_string "t:n:f:b:s:vh?ixjl12"
+#define dasdview_getopt_string "t:n:f:b:s:vhixjl12"
 
 /* struct options for getopt */
 static struct option dasdview_getopt_long_options[]=
