@@ -3,8 +3,7 @@
  * Author(s)......: Volker Sameske <sameske@de.ibm.com>
  *                  Horst Hummel   <horst.hummel@de.ibm.com>
  *                  Gerhard Tonn   <ton@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2001-2004
+ * Copyright IBM Corp. 2001,2007
  */
 
 #include <getopt.h>
@@ -14,10 +13,10 @@
 #include "fdasd.h"
 
 /* Full tool name */
-static const char tool_name[] = "zSeries DASD partitioning program";
+static const char tool_name[] = "fdasd: zSeries DASD partitioning program";
 
 /* Copyright notice */
-static const char copyright_notice[] = "(C) Copyright IBM Corp. 2001-2005";
+static const char copyright_notice[] = "Copyright IBM Corp. 2001, 2006";
 
 /*
  * Print version information.
@@ -315,9 +314,7 @@ fdasd_usage (void)
 		                          "using information\n"
                 "                         found in CONFIGFILE\n"
 		"-i, --volser             Print volume serial\n"
-		"-p, --table              Print partition table\n"
-		"\n"
-		"Please report bugs to: linux390@de.ibm.com\n");
+		"-p, --table              Print partition table\n");
 }
 
 
@@ -438,7 +435,6 @@ fdasd_parse_options (fdasd_anchor_t *anc, struct fdasd_options *options,
 			print_version();
 			fdasd_exit(anc, 0);
 		case 'h':
-		case '?':
 			fdasd_usage ();
 			fdasd_exit(anc, 0);
 		case 'l':
@@ -478,8 +474,9 @@ fdasd_parse_options (fdasd_anchor_t *anc, struct fdasd_options *options,
 			/* End of options string - start of devices list */
 			break;
 		default:
-			fdasd_error(anc, parser_failed, 
-				    "Invalid command line detected\n");
+			fprintf(stderr, "Try 'fdasd --help' for more"
+					" information.\n");
+			fdasd_exit(anc, 1);
 		}
 	} while (opt != -1);
 
