@@ -2,8 +2,7 @@
  * File...........: s390-tools/fdasd/fdasd.h
  * Author(s)......: Volker Sameske <sameske@de.ibm.com>
  *                  Horst Hummel   <Horst.Hummel@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2001-2002
+ * Copyright IBM Corp. 2001,2007
  */
 
 #ifndef FDASD_H
@@ -100,7 +99,7 @@ static struct option fdasd_long_options[] = {
 };
 
 /* Command line option abbreviations */
-static const char option_string[] = "?vasrl:c:hpik";
+static const char option_string[] = "vasrl:c:hpik";
 
 struct fdasd_options {
 	char *device;
