@@ -2,7 +2,7 @@
 #
 # start_hsnc.sh
 #
-# Copyright 2003 IBM Corporation
+# Copyright IBM Corp. 2003, 2006.
 # Author(s): Utz Bacher <utz.bacher@de.ibm.com>
 #
 # wrapper start script for ip_watcher.pl, also cleanup, when ip_watcher.pl
@@ -36,8 +36,8 @@ function __usage
 
 function PrintVersion
 {
-        echo "$script_name version $version (S390 Tools %S390_TOOLS_VERSION%)"
-        echo "(C) Copyright IBM Corp. 2003-2004"
+        echo "$script_name version %S390_TOOLS_VERSION%($version)."
+        echo "Copyright IBM Corp. 2003, 2006."
 }
 #
 # main
@@ -63,7 +63,7 @@ fi
 case "$1" in
    -v | --version  ) PrintVersion
      	     exit 1 ;;
-   -h | --help | "?"  ) __usage ;;               
+   -h | --help  ) __usage ;;               
 esac
 
 if [ X${1}X != XX ] && [ $kernel_version = 2.4 ] ; then
