@@ -1,11 +1,10 @@
 /*
  * File...........: s390-tools/fdasd/vtoc.c
  * Author(s)......: Volker Sameske <sameske@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2001-2002
- *           
+ * Copyright IBM Corp. 2001,2007
+ *
  * History of changes (starts March 2002)
- * 2002-03-12 removed dependency to kernel headers          
+ * 2002-03-12 removed dependency to kernel headers
  * 2003-01-30 changed DS4VTOCI from 0x20 to 0xa0
  */
 
@@ -178,8 +177,7 @@ static void vtoc_error(enum failure why, char *s1, char *s2)
 /*
  *
  */
-char * vtoc_ebcdic_enc (unsigned char source[LINE_LENGTH],
-			unsigned char target[LINE_LENGTH], int l) 
+char * vtoc_ebcdic_enc (char *source, char *target, int l) 
 {
         int i;
 
@@ -193,8 +191,7 @@ char * vtoc_ebcdic_enc (unsigned char source[LINE_LENGTH],
 /*
  *
  */
-char * vtoc_ebcdic_dec (unsigned char source[LINE_LENGTH],
-			unsigned char target[LINE_LENGTH], int l) 
+char * vtoc_ebcdic_dec (char *source, char *target, int l) 
 {
         int i;
 
