@@ -1,7 +1,7 @@
 /*
  * File...........: ibmOSAMib.c
  * Author(s)......: Thomas Weber <tweber@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2002
+ * Copyright IBM Corp. 2002,2007
  *
  * History of changes:
  * none                 
@@ -221,7 +221,7 @@ void init_ibmOSAMib(void) {
 			 "init_ibmOSAMib(): "
 			 "Can't get MIB information for network interfaces\n"
 			 "Cannot start subagent...exiting...\n" );
-
+		break;
 	      default:
 		fprintf( stderr, "init_ibmOSAMib(): "
 			 "ioctl() failed - reason %s\n"
@@ -548,7 +548,7 @@ unsigned char* var_DisplayStr( struct variable *vp,
     	                       WriteMethod **write_method)
 {
   /* variables for returning a display string to the subagent driving code */
-  static unsigned char string[SPRINT_MAX_LEN];
+  static char string[SPRINT_MAX_LEN];
   char                 time_buf[TIME_BUF_SIZE]; /* date/time buffer */
   
   int  ifIndex;     /* IF-MIB ifIndex of the OSA device that is queried for data */
@@ -595,12 +595,12 @@ unsigned char* var_DisplayStr( struct variable *vp,
 
   if ( vp->type == ASN_OCTET_STR)  
     {
-      if ( get_res->len > SPRINT_MAX_LEN )
+      if ( get_res->len >= SPRINT_MAX_LEN )
 	{
 	  get_time( time_buf );	
 	  snmp_log( LOG_ERR, "%s var_DisplayStr(): "
 		    "IPA data length %d  for Display "
-		    "String > SPRINT_MAX_LEN (%d  bytes)\n"
+		    "String >= SPRINT_MAX_LEN (%d  bytes)\n"
 		    "var_ibmOSAMib(): rejected Get/Getnext request\n"
 		    ,time_buf, get_res->len, SPRINT_MAX_LEN );
 	  free( get_cmd );
