@@ -1,7 +1,7 @@
 /*
  * File...........: ibmOSAMibUtil.c
  * Author(s)......: Thomas Weber <tweber@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2002
+ * Copyright IBM Corp. 2002,2007
  *
  * History of changes:
  * 07/29 added '-x agentx_socket' parm to usage message
@@ -42,6 +42,9 @@ extern TABLE_OID* oid_list_head;
 /* proc file filedescriptor. opened in osasnmpd.c */
 extern int proc_fd;
 
+
+
+
 /**********************************************************************
  * str_to_oid_conv():
  *  This function converts an OID string in an OID u_long array used
@@ -133,12 +136,6 @@ int oid_to_str_conv (oid* ul_oid, size_t length, char* uc_oid )
 
       for ( i=0; i < length; i++)
         {
-          if ( ul_oid[i] < 0 )
-            {
-              valid = FALSE;
-              break;
-            }
- 
           /* convert and append OID digit to return string */ 
           if (i == 0)       
             sprintf( buffer, "%lu", ul_oid[i] );
@@ -706,7 +703,7 @@ int register_tables ( void* mib_data,
       } /* end if */
     } /* end if */
     /* if OID was found, set insert OID to exact match OID */
-    else if ( src_oid == OID_FOUND )
+    else   /* src_oid == OID_FOUND */
       ins_oid = oid_ptr;  
     
     /****************************************************************/
@@ -1334,7 +1331,7 @@ void update_mib_info ()
 	    strcpy( ifr.ifr_name, if_list[i].if_Name );         /* add interface name */       
 	    ifr.ifr_ifru.ifru_data = (char*) buffer;            /* add data buffer    */ 
 	
-	    if ( ioctl( sd, QETH_QUERY_IPA_DATA, &ifr ) < 0 )
+	    if ( ioctl( sd,SIOC_QETH_ADP_SET_SNMP_CONTROL, &ifr ) < 0 )
 	      {
 		error_code = errno;
 		get_time( time_buf );
@@ -1536,8 +1533,9 @@ int query_IF_MIB ( IF_LIST** ifList )
   snmp_sess_init( &session );                                           
   session.peername  = NET_SNMP_PEERNAME;       
   session.version   = SNMP_VERSION_2c;      /* use SNMPv2c */
-  session.community = NET_SNMP_COMMUNITY;   /* SNMPv2c community name */
-  session.community_len = strlen(session.community);
+  /* SNMPv2c community name */
+  session.community = (unsigned char*)NET_SNMP_COMMUNITY;
+  session.community_len = strlen((const char*)session.community);
   session.timeout = 300 * 1000000L;
    
   /* Open the session */
@@ -1606,6 +1604,7 @@ int query_IF_MIB ( IF_LIST** ifList )
 	       * */
 	      (*ifList)[i].is_OSAEXP = FALSE;
 	      (*ifList)[i].kerIndex = 0;
+	      (*ifList)[i].ifIndex = 0;
 
 	      /* get values for ifIndex/ifDescr from response PDU 
 	       *  FIXME: (workaround) compare ifDescr values 
@@ -1620,16 +1619,19 @@ int query_IF_MIB ( IF_LIST** ifList )
 	          {
 		    if ( if_Number == 0 )
 		      {	   
-		         strncpy( (*ifList)[0].if_Name, vars->val.string, vars->val_len );
+		         strncpy((char*)((*ifList)[0]).if_Name,
+				 (const char*)vars->val.string, vars->val_len);
 			 (*ifList)[0].if_Name[vars->val_len] = '\0';
 		      }
 	   	    else
 		      {
-                        if ( strncmp( (*ifList)[if_Number-1].if_Name, vars->val.string,
-			  	     vars->val_len ) !=0 )
+                        if (strncmp((const char*)(*ifList)[if_Number-1].if_Name,
+				    (const char*)vars->val.string,
+			  	     vars->val_len) !=0)
 		          {
-		            strncpy( (*ifList)[if_Number].if_Name, vars->val.string, 
-				     vars->val_len );
+		            strncpy((char*)(*ifList)[if_Number].if_Name,
+				    (const char*)vars->val.string,
+				     vars->val_len);
 	                    (*ifList)[if_Number].if_Name[vars->val_len] = '\0';
 			    valid = TRUE;
                           }
@@ -1738,7 +1740,7 @@ int query_OSA_EXP ( IF_LIST** ifList, int if_Number )
 
 	memset(&ifr,0,sizeof(ifr));
 	strncpy(ifr.ifr_name, (*ifList)[j].if_Name,IFNAME_MAXLEN);
-        ret = ioctl(sd, QETH_CHECK_OSA_DEVICE, &ifr);
+        ret = ioctl(sd, SIOC_QETH_GET_CARD_TYPE, &ifr);
 	if (ret>0) {
       		(*ifList)[j].is_OSAEXP = TRUE;
 		(*ifList)[j].kerIndex  = (*ifList)[j].ifIndex;
@@ -1772,8 +1774,6 @@ int get_time( char* buffer )
   
 } /* end get_time () */
 
-static const char contact_information[] = "linux390@de.ibm.com";
-
 static const char* usage_text[] = {
 "Usage:  osasnmpd [-h] [-v] [-l LOGFILE] [-A] [-f] [-L] [-P PIDFILE]",
 "                 [-x SOCKADDR]",
@@ -1801,6 +1801,6 @@ void usage()
 
 	for (i=0; i < sizeof(usage_text) / sizeof(usage_text[0]); i++)
 		printf("%s\n", usage_text[i]);
-	printf("Please report bugs to: %s\n", contact_information);
 	exit(0);
+  
 } /* end usage() */
