@@ -1,8 +1,7 @@
 /*
  * File...........: qetharp24.c
  * Author(s)......: Frank Pavlic <pavlic@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation, IBM Deutschland Entwicklung GmbH, 2001
+ * Copyright IBM Corp. 2001,2007
  *
  * History of changes (starts February 2002)
  *
@@ -34,6 +33,7 @@
 #include <unistd.h>
 #include <getopt.h>
 #include "qetharp24.h"
+#include "zt_common.h"
 
 /*****************************************************
  *            Function implementation                *
@@ -430,7 +430,6 @@ int main(int argc, char **argv)
 	int index,c,result;
 	option_info_t info;
 
-	opterr=0;
 	result=0;
 
 
@@ -445,14 +444,13 @@ int main(int argc, char **argv)
 
 		switch (c) 
 		{
-		case '?':	
 		case 'h':
 		        qetharp_usage();
 			exit(0);
 		case 'v':
-			printf( "\n%s version %s (S390 Tools %s)\n", 
-				argv[0],VERSION_NO,RELEASE_STRING );
-			printf( "%s\n",COPYRIGHT );
+			printf( "qetharp: version %s (%s).\n",
+				RELEASE_STRING, VERSION_NO);
+			printf( "%s\n",COPYRIGHT);
 			exit(0);
 		case 'q':
 			info.dev_name = optarg;
@@ -485,8 +483,9 @@ int main(int argc, char **argv)
 			info.mac_flag = OPTION_INFO_MAC;
 			break;
 		default:
-			qetharp_usage();
-			exit(0);
+			fprintf(stderr, "Try 'qetharp --help' for more"
+					" information.\n");
+			exit(1);
 		}
 	}
 	result = qetharp_parse_info(&info);
