@@ -122,10 +122,7 @@ typedef struct osa_delarp_data_t {
  *            Declarations for version string        *
  *****************************************************/
 #define VERSION_NO "0.02"
-#define COPYRIGHT "\(C) Copyright IBM Corp. 2003-2004\n\n"
-#define STRINGIFY_1(x)   #x
-#define STRINGIFY(x)     STRINGIFY_1(x)
-#define RELEASE_STRING   STRINGIFY (S390_TOOLS_RELEASE)
+#define COPYRIGHT "Copyright IBM Corp. 2003, 2006."
 
 static struct option qetharp_options[]=
 {
