@@ -4,9 +4,7 @@
  *                  (adaptations to 2.6 kernel)
  * originally written by: Frank Pavlic <pavlic@de.ibm.com>
  * 
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation 2001,2004
- *
+ * Copyright IBM Corp. 2001,2007
  */
 
 #include <stdio.h>
@@ -23,6 +21,7 @@
 #include <unistd.h>
 #include <getopt.h>
 #include "qetharp26.h"
+#include "zt_common.h"
 
 /*****************************************************
  *            Function implementation                *
@@ -414,7 +413,6 @@ int main(int argc, char **argv)
 	int index,c,result;
 	struct option_info info;
 
-	opterr=0;
 	result=0;
 
 
@@ -429,13 +427,12 @@ int main(int argc, char **argv)
 
 		switch (c) 
 		{
-		case '?':	
 		case 'h':
 		        qetharp_usage();
 			exit(0);
 		case 'v':
-			printf( "\n%s version %s (S390 Tools %s)\n", 
-				argv[0],VERSION_NO,RELEASE_STRING );
+			printf("qetharp: version %s (%s).\n",
+				RELEASE_STRING, VERSION_NO);
 			printf( "%s\n",COPYRIGHT );
 			exit(0);
 		case 'q':
@@ -469,8 +466,9 @@ int main(int argc, char **argv)
 			info.mac_flag = OPTION_INFO_MAC;
 			break;
 		default:
-			qetharp_usage();
-			exit(0);
+			fprintf(stderr, "Try 'qetharp --help' for more"
+					" information.\n");
+			exit(1);
 		}
 	}
 	result = qetharp_parse_info(&info);
