@@ -4,8 +4,7 @@
  *                  (adaptations to 2.6 kernel)
  * originally written by: Frank Pavlic <pavlic@de.ibm.com>
  * 
- * Bugreports.to..: <Linux390@de.ibm.com>
- * (C) IBM Corporation 2001,2004
+ * Copyright IBM Corp. 2001, 2006.
  *
  */
 #ifndef __QETHARP_26_H__
@@ -67,10 +66,7 @@
  *            Declarations for version string        *
  *****************************************************/
 #define VERSION_NO "0.02"
-#define COPYRIGHT "\(C) Copyright IBM Corp. 2003-2004\n\n"
-#define STRINGIFY_1(x)   #x
-#define STRINGIFY(x)     STRINGIFY_1(x)
-#define RELEASE_STRING   STRINGIFY (S390_TOOLS_RELEASE)
+#define COPYRIGHT "Copyright IBM Corp. 2003, 2006."
 
 static struct option qetharp_options[]=
 {
