@@ -2,33 +2,63 @@
  * File...........: s390-tools/tape390/tape390_display.c
  * Author(s)......: Despina Papadopoulou <despina_p@de.ibm.com>
  *                  Stefan Bader <shbader@de.ibm.com>
- * Bugreports.to..: <Linux390@de.ibm.com>
- * 
- * Copyright (C) 2002 IBM Deutschland Entwicklung GmbH, IBM Corporation
  *
- * Description: The tape390_display tool is used to display 
+ * Copyright IBM Corp. 2002, 2006.
+ *
+ * Description: The tape390_display tool is used to display
  *              messages on the display unit of a zSeries tape drive.
  *
  */
 #include <ctype.h>
-#include <stdio.h> 
+#include <stdio.h>
 #include <unistd.h>
-#include <fcntl.h> 
 #include <libgen.h>
 #include <string.h>
 #include <stdlib.h>
 #include <getopt.h>
 #include <sys/ioctl.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <linux/mtio.h>
+#include "tape390_common.h"
+#include "zt_common.h"
 
-#include "tape390.h"
+#define TAPE390_DISPLAY _IOW('d', 1, struct display_struct)
+
+/*
+ * The TAPE390_DISPLAY belongs to linux-2.5/include/asm-s390/tape390.h
+ *
+ * The TAPE390_DISPLAY ioctl calls the Load Display command
+ * which transfers 17 bytes of data from the channel to the subsystem:
+ *     - 1 format control byte, and
+ *     - two 8-byte messages
+ *
+ * Format control byte:
+ *   0-2: New Message Overlay
+ *     3: Alternate Messages
+ *     4: Blink Message
+ *     5: Display Low/High Message
+ *     6: Reserved
+ *     7: Automatic Load Request
+ *
+ */
+#define TAPE_MSGTYPE_STANDARD           0
+#define TAPE_MSGTYPE_UNLOAD             1
+#define TAPE_MSGTYPE_LOAD               2
+#define TAPE_MSGTYPE_NOOP               3
+#define TAPE_MSGTYPE_UNLOAD_LOAD        7
+
+typedef struct display_struct {
+	struct {
+		unsigned char   type            :3;
+		unsigned char   alternate       :1;
+		unsigned char   blink           :1;
+		unsigned char   use_second      :1;
+		unsigned char   reserved        :1;
+		unsigned char   load_request    :1;
+	}                       cntrl;
+	char                    message1[8];
+	char                    message2[8];
+} __attribute__ ((packed))      display_struct;
 
 /*  definitions  */
-#define STRINGIFY1(x)	#x
-#define STRINGIFY(x)	STRINGIFY1(x)
-
 char *help_text= \
 	"tape390_display: display one or two 8-byte messages on the display"
 	"unit of a tape drive\n"
@@ -42,6 +72,8 @@ char *help_text= \
 	"\t\t(this option has only effect with a single message)\n"
 	"\t-h | --help\n"
 	"\t\tprint this text\n"
+	"\t-v | --version\n"
+	"\t\toutput version information and exit\n"
 	"\t-l | --load\n"
 	"\t\twill try to load the next tape if the loader is in system mode\n"
 	"\t-q | --quiet\n"
@@ -61,8 +93,7 @@ char *help_text= \
 	"characters\n"
 	"might be displayed on all tape devices. Special characters that "
 	"are supported\n"
-	"for 3490 are '@$#,./()*&+-=%|:_<>?;'.\n"
-	"\n";
+	"for 3490 are '@$#,./()*&+-=%|:_<>?;'.\n";
 
 int	quiet = 0;
 
@@ -118,14 +149,14 @@ strchkcpy(char *tgt, const char *src) {
 
 int main(int argc, char *argv[]) {
 
-	char			*options = "hblqt:V";
+	char			*options = "hblqt:v";
 	struct option		 long_options[] = {
 		{ "help",	 no_argument,		NULL, 'h' },
 		{ "blink",	 no_argument,		NULL, 'b' },
 		{ "load",	 no_argument,		NULL, 'l' },
 		{ "quiet",	 no_argument,		NULL, 'q' },
 		{ "type",	 required_argument,	NULL, 't' },
-		{ "version",     no_argument,           NULL, 'V' },
+		{ "version",     no_argument,           NULL, 'v' },
 		{ NULL,		 0,			NULL, 0   }
 	};
 	char			*pathname;
@@ -133,6 +164,9 @@ int main(int argc, char *argv[]) {
 	int			 fd, ret = 0;
 	struct display_struct	 ds;
 
+	/* set name of program */
+	set_prog_name(basename(argv[0]));
+
 	memset(&ds, 0, sizeof(ds));
 	ds.cntrl.type = TAPE_MSGTYPE_STANDARD;
 
@@ -162,26 +196,16 @@ int main(int argc, char *argv[]) {
 				ds.cntrl.type = type;
 				break;
 			}
-			case 'V': {
-				char *cmdver;
-				char *s;
-
-				s = "$Revision: 1.9 $";
-				cmdver = strdup(s + 11);
-				if (cmdver)
-					cmdver[strlen(cmdver)-2] = '\0';
-				
-				printf("%s (%s version %s)\n",
-					STRINGIFY(S390_TOOLS_RELEASE),
-					basename(argv[0]),
-					cmdver
-				);
-				free(cmdver);
+			case 'v': {
+				printf("tape390_display: zSeries tape "
+				       "display control program version %s.\n",
+					RELEASE_STRING);
+				printf("Copyright IBM Corp. 2002, 2006.\n");
 				exit(0);
-				break;
 			}
 			default:
-				fprintf(stderr, "invalid option(%c)\n", c);
+				fprintf(stderr, "Try '%s --help' for more"
+						" information.\n",prog_name);
 				exit(1);
 		}
 	}
@@ -247,24 +271,19 @@ int main(int argc, char *argv[]) {
 		exit(1);
 	}
 
-	fd = open(pathname, O_RDONLY);
-	if (fd < 0) {
-	        fprintf(stderr, "Cannot open device %s.\n", pathname);
-	        exit(1);
-	}
+	/* check whether specified device node is tape */
+	if (is_not_tape(pathname))
+		exit(EXIT_MISUSE);
+
+	/* open device                                 */
+	fd = open_tape(pathname);
 
 	ret = ioctl(fd, TAPE390_DISPLAY, &ds);
-        if (ret != 0)
-                fprintf(stderr, "TAPE390_DISPLAY failed\n");
+	if (ret != 0)
+		fprintf(stderr, "TAPE390_DISPLAY failed\n");
 
-        close(fd);
+	close(fd);
 
-        return ret;
+	return ret;
 }
 
-
-
-
-
-
-
