@@ -2,7 +2,7 @@
  * dump.cpp
  *  dump base class
  * 
- *  Copyright (C) 2004,2005 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *  Copyright IBM Corp. 2004, 2006.
  *   
  *  Author(s): Michael Holzheu
  */
@@ -22,9 +22,9 @@ s390TodToTimeval(uint64_t todval, struct timeval *xtime)
 	xtime->tv_usec = todval % 1000000;
 }
 
-Dump::Dump(const char *filename)
+Dump::Dump(const char *filename, const char *mode)
 {
-	fh = fopen(filename, "r+");
+	fh = fopen(filename, mode);
 	if(!fh){
 		throw(DumpErrnoException("Open dump file failed!"));
 	}
