@@ -2,7 +2,7 @@
  * dump.h
  *  dump base class
  * 
- *  Copyright (C) 2004,2005 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *  Copyright IBM Corp. 2004, 2006.
  *   
  *  Author(s): Michael Holzheu
  */
@@ -49,7 +49,7 @@ public:
 class Dump
 {
 public:
-	Dump(const char* filename);
+	Dump(const char* filename, const char* mode);
 	Dump(void) : fh(0)
 	{}
 	virtual ~Dump(void);
