@@ -6,7 +6,8 @@
  *    - VMDump64
  *    - VMDump64Big
  *    - VMDump32
- *  Copyright (C) 2004,2005 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *
+ *  Copyright IBM Corp. 2004, 2006.
  *   
  *  Author(s): Michael Holzheu
  */
@@ -86,7 +87,7 @@ VMDump::getDumpType(const char* inputFileName)
 	}
 }
 
-VMDump::VMDump(const char *fileName) : Dump(fileName)
+VMDump::VMDump(const char *fileName) : Dump(fileName, "rb")
 {
 	char fmbk_id[8] = {0xc8, 0xc3, 0xd7, 0xc4, 0xc6, 0xd4, 0xc2, 0xd2};
 	
