@@ -4,11 +4,13 @@
  *		 and writes its contents to standard output,
  *		 which you can redirect to a specific file.
  *
- *    Copyright (C) 2001 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *    Copyright IBM Corp. 2001, 2006.
  *    Author(s): Despina Papadopoulou
+ *               Frank Munzert <munzert@de.ibm.com>
  */
 
 #include "zgetdump.h"
+#include "zt_common.h"
 #include <stdio.h> 
 #include <unistd.h>
 #include <stdlib.h>
@@ -16,16 +18,26 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <linux/mtio.h>
+#include <sys/utsname.h>
 #include <fcntl.h> 
 #include <ctype.h>
 #include <string.h>
 #include <time.h>
 #include <getopt.h>
+#include <sys/mtio.h>
 
 #define HEADER_SIZE 4096
 #define BLOCK_SIZE 32768
 #define IS_DASD -1
+#define MAGIC_LENGTH 10
+#define PARTN_MASK ((1 << 2) -1)
+#define MAGIC_OFFSET_ECKD 0x3000
+#define MAGIC_OFFSET_FBA -0x1000
+#define HEXINSTR "\x0d\x10\x47\xf0"      /* BASR + 1st halfword of BC    */
+#define ARCH_S390  1
+#define ARCH_S390X 2
+#define VERSION_NO_DUMP_DEVICE -1
+
 
 #if defined(__s390x__)
 	#define FMT64 "l"
@@ -33,17 +45,14 @@
 	#define FMT64 "ll"
 #endif
 
-#define STRINGIFY_1(x)		  #x
-#define STRINGIFY(x)		  STRINGIFY_1(x)
-
-#define RELEASE_STRING   STRINGIFY(S390_TOOLS_RELEASE)
-
 /*  definitions  */
 
 char *help_text=
-"\nThe zgetdump tool takes as input the dump device\n"\
+"The zgetdump tool takes as input the dump device\n"\
 "and writes its contents to standard output,\n"\
 "which you can redirect to a specific file.\n\n"\
+"zgetdump can also check, whether a DASD device\n"\
+"contains a valid dumper.\n\n"\
 "Usage:\n"\
 "Copy dump from <dumpdevice> to stdout:\n"\
 "       > zgetdump <dumpdevice>\n"\
@@ -51,38 +60,41 @@ char *help_text=
 "       > zgetdump [-i | --info] <dumpdevice>\n"\
 "Print dump header and check if dump is valid - for all volumes of a mv tape dump:\n"\
 "       > zgetdump [-i | --info] [-a | --all] <dumpdevice>\n"\
+"Check dump device:\n"\
+"       > zgetdump [-d | --device <device>\n"\
 "Print version info:\n"\
 "       > zgetdump [-v | --version]\n"\
 "Print this text:\n"\
 "       > zgetdump [-h | --help]\n\n"\
-"Example:\n"\
-"> zgetdump /dev/dasdc1 > dump_file\n\n";
+"Examples:\n"\
+"> zgetdump /dev/dasdc1 > dump_file\n"\
+"> zgetdump -d /dev/dasdc\n";
 
 char *usage_note=
 "Usage:\n"\
 "> zgetdump <dumpdevice>\n"\
 "> zgetdump -i <dumpdevice>\n"\
 "> zgetdump -i -a <dumpdevice>\n"\
+"> zgetdump -d <device>\n"\
 "More info:\n"\
 "> zgetdump -h\n";
 
 /* Version info */
-static const char version_text[] = "zgetdump: version "RELEASE_STRING;
+static const char version_text[] = "zgetdump: version "RELEASE_STRING".";
 
 /* Copyright notice */
-static const char copyright_notice[] = "Copyright (C) 2001-2004 "
-				       "IBM Deutschland Entwicklung GmbH, "
-				       "IBM Corporation";
+static const char copyright_notice[] = "Copyright IBM Corp. 2001, 2006.";
 
 static struct option longopts[] = {
 	{"info",no_argument,0,'i'},
 	{"help",no_argument,0,'h'},
 	{"version",no_argument,0,'v'},
 	{"all",no_argument,0,'a'},
+	{"device",no_argument,0,'d'},
 	{0,0,0,0}
 };
 
-#define OPTSTRING "iavh"
+#define OPTSTRING "iavhd"
 
 /* global variables */
 
@@ -93,6 +105,7 @@ struct timeval h_time_begin, h_time_end;
 
 int  option_a_set = 0;
 int  option_i_set = 0;
+int  option_d_set = 0;
 char device_name[1024];
 
 /* prototypes */
@@ -105,6 +118,109 @@ void s390_tod_to_timeval(uint64_t todval, struct timeval *xtime);
 
 /* end of definitions  */
 
+/* 	Use uname to check whether we run s390x kernel 	*/
+int check_kernel_mode()
+{
+	struct utsname uname_struct;
+	if (uname(&uname_struct)) {
+		fprintf(stderr, "Unable to get name and information about " 
+                        "current kernel. \n");
+                perror("");
+		return 1;
+	}
+	if (strncmp(uname_struct.machine, "s390x", 5) == 0) {
+                fprintf(stderr, "=========================================="
+                        "=======\n");
+		fprintf(stderr, "WARNING: You are running an s390x (ESAME) " 
+                        "kernel.\n");
+		fprintf(stderr, "         Your dump tool however is s390 " 
+                        "(ESA).\n"); 
+                fprintf(stderr, "=========================================="
+                        "=======\n");
+	}
+	return 0;
+}
+
+/* 	Read magic number provided in eckd2dump or fba2dump from DASD device */ 
+/*      to buffer 							     */
+int read_magic(int fd, int32_t offset, char *buffer, int whence)
+{
+	int n_read;
+        lseek(fd,offset,whence);
+        n_read  = read(fd, buffer, MAGIC_LENGTH);
+        if (n_read != MAGIC_LENGTH) {
+                fprintf(stderr, "Read of device '%s' failed. \n", device_name);
+                return 1;
+        }
+	else
+		return 0;
+}
+
+/* 	Use stat to check whether user provided input is a block device 	*/
+int check_device(char *device)
+{
+	struct stat stat_struct;
+        if (stat(device, &stat_struct)) {
+                fprintf(stderr, "Unable to get device status for " 
+                        "'%s'. \n", device);
+                perror("");
+                return 1;
+        }
+        if (!(S_ISBLK(stat_struct.st_mode))) {
+                fprintf(stderr, "'%s' is not a block device. \n", device_name);
+                return 1;
+        }
+        if (minor (stat_struct.st_rdev) & PARTN_MASK) {
+                fprintf(stderr, "Partition '%s' (%d/%d) detected where device is "
+                         "required.\n", device_name,
+                         (unsigned short) major(stat_struct.st_rdev),
+                         (unsigned short) minor(stat_struct.st_rdev));
+                return 1;
+        }
+	return 0;
+}
+
+int check_for_fba_device(int fd, int *version, int *arch)
+{
+        char read_buf[MAGIC_LENGTH];
+        if (read_magic(fd,MAGIC_OFFSET_FBA,read_buf,SEEK_END))
+		return 1;
+        if (strncmp(read_buf,"ZDFBA31",7)==0) {
+                *version = read_buf[7];
+                *arch = ARCH_S390;
+        } else if (strncmp(read_buf,"ZDFBA64",7)==0) {
+                *version = read_buf[7];
+                *arch = ARCH_S390X;
+        } else if (memcmp(read_buf, HEXINSTR, 4)==0 &&
+                 read_buf[8]=='\x0d' && read_buf[9]=='\xd0')
+		/* We found basr r13,0 (old dumper) */
+                *version = 0;
+        else
+                *version = VERSION_NO_DUMP_DEVICE;
+        return 0;
+}
+
+int check_for_eckd_device(int fd, int *version, int *arch)
+{
+        char read_buf[MAGIC_LENGTH];
+        if (read_magic(fd,MAGIC_OFFSET_ECKD,read_buf,SEEK_SET))
+		return 1;
+        if (strncmp(read_buf,"ZECKD31",7)==0) {
+                *version = read_buf[7];
+                *arch = ARCH_S390;
+        } else if (strncmp(read_buf,"ZECKD64",7)==0) {
+                *version = read_buf[7];
+                *arch = ARCH_S390X;
+        } else if (memcmp(read_buf, HEXINSTR, 4)==0 &&
+                 read_buf[8]=='\x0d' && read_buf[9]=='\xd0')
+		/* We found basr r13,0 (old dumper) */
+                *version = 0;
+        else
+                *version = VERSION_NO_DUMP_DEVICE;
+        return 0;
+}
+
+
 void s390_tod_to_timeval(uint64_t todval, struct timeval *xtime)
 {
     /* adjust todclock to 1970 */
@@ -121,11 +237,10 @@ int open_dump(char *pathname)
 	int fd;
 	fd = open(pathname, O_RDONLY);
 	if (fd == -1){
-		fprintf(stderr, "\nCannot open dump device %s. \n\n", pathname);
+		fprintf(stderr, "Cannot open dump device %s. \n", pathname);
 		exit(1);
-	}
-	else
-		fprintf(stderr, "\nDump device: %s\n", pathname);
+	} else
+		fprintf(stderr, "Dump device: %s\n", pathname);
 	return fd;
 }
 
@@ -182,12 +297,12 @@ void get_header(int fd, int d_type)
 	ssize_t	n_read;
 
 	n_read = read(fd, &header, HEADER_SIZE);
-	if(n_read == -1){
+	if (n_read == -1){
 		perror("Cannot read dump header");
 		close(fd);
 		exit(1);
 	}
-	if((d_type == IS_DASD) && ((header.dh_magic_number == DUMP_MAGIC_LKCD) || (header.dh_magic_number == DUMP_MAGIC_LIVE))){
+	if ((d_type == IS_DASD) && ((header.dh_magic_number == DUMP_MAGIC_LKCD) || (header.dh_magic_number == DUMP_MAGIC_LIVE))){
 		print_lkcd_header(fd);
 		exit(0);
 	}
@@ -209,7 +324,7 @@ void get_header(int fd, int d_type)
 /*	of a multi-volume tape dump	*/
 
 	if ((d_type == IS_DASD) || (header.dh_volnr == 0)){
-		if(header.dh_magic_number != DUMP_MAGIC_S390){
+		if (header.dh_magic_number != DUMP_MAGIC_S390){
 			fprintf(stderr, "===================================================\n");
 			fprintf(stderr, "WARNING: This does not look like a valid s390 dump!\n");
 			fprintf(stderr, "===================================================\n");
@@ -224,11 +339,11 @@ void get_header(int fd, int d_type)
 		fprintf(stderr, "Page size:\t %d\n",header.dh_page_size);
 		fprintf(stderr, "Dumped memory:\t %"FMT64"d\n", header.dh_memory_size);
 		fprintf(stderr, "Dumped pages:\t %u\n", header.dh_num_pages);
-		if(header.dh_version >= 3){
+		if (header.dh_version >= 3){
 			fprintf(stderr, "Real memory:\t %"FMT64"d\n", header.dh_real_memory_size);
 		}
 		fprintf(stderr, "cpu id:\t\t 0x%"FMT64"x\n", header.dh_cpu_id);
-		if(header.dh_version >= 2){
+		if (header.dh_version >= 2){
 			switch(header.dh_arch){
 				case 1: fprintf(stderr, "System Arch:\t s390 (ESA)\n");
 					break;
@@ -262,12 +377,12 @@ void write_header(int fd)
 	ssize_t rc;
 	memcpy(read_buffer,&header,sizeof(header));
 	rc = write(STDOUT_FILENO, read_buffer, header.dh_header_size);
-	if(rc == -1) {
+	if (rc == -1) {
 		perror("\nwrite failed");
 		exit(1);
 	}
-	if(rc < header.dh_header_size) {
-		fprintf(stderr,"\nwrite failed: No space left on device\n");
+	if (rc < header.dh_header_size) {
+		fprintf(stderr,"write failed: No space left on device\n");
 		exit(1);
 	}
 }
@@ -290,20 +405,19 @@ int get_dump(int fd, int d_type)
 		do {
 			n_read = read(fd, read_buffer, BLOCK_SIZE);
 			n_written = write(STDOUT_FILENO, read_buffer, n_read);
-			if(n_written == -1) {
+			if (n_written == -1) {
 				perror("\nwrite failed");
 				exit(1);
 			}
-			if(n_written < n_read) {
-				fprintf(stderr,"\nwrite failed: No space left on device\n");
+			if (n_written < n_read) {
+				fprintf(stderr,"write failed: No space left on device\n");
 				exit(1);
 			}
 		       	i += n_read;
 			if (i % (header.dh_memory_size/32) == 0)
 				fprintf(stderr, ".");
 		} while (i<header.dh_memory_size && n_read != 0 && n_written >= 0);
-	}
-	else {	
+	} else {	
 
 	/*	device is tape			*/
 	/*      write to stdout while not	*/
@@ -319,20 +433,18 @@ int get_dump(int fd, int d_type)
 				fprintf(stderr, "\nEnd of Volume reached.\n");
 				ret=1;
 				break;
-			}
-			else if (strncmp(read_buffer,"DUMP_END",8) == 0){
+			} else if (strncmp(read_buffer,"DUMP_END",8) == 0){
 				ret = 2;
 				break;
-			}
-			else {
+			} else {
 				ssize_t rc;
 				rc = write(STDOUT_FILENO, read_buffer, n_read);
-				if(rc == -1){
+				if (rc == -1){
 					perror("\nwrite failed");
 					exit(1);
 				}
-				if(rc < n_read){
-					fprintf(stderr,"\nwrite failed: No space left on device\n");
+				if (rc < n_read){
+					fprintf(stderr,"write failed: No space left on device\n");
 					exit(1);
 				}
 			}
@@ -364,8 +476,7 @@ int dump_end_times(int fd)
 	if ((strncmp(end_marker.end_string,"DUMP_END", 8)==0) && ((h_time_end.tv_sec - h_time_begin.tv_sec) >= 0)){
 		fprintf(stderr, "\nDump ended on:\t %s\n", ctime(&h_time_end.tv_sec));
 		ret=0;
-	}
-	else
+	} else
 		ret=-1;
 	return ret;
 }
@@ -429,8 +540,7 @@ void load_next(fd)
 	if (ret != 0){
 		fprintf(stderr, "Tape operation LOAD failed.\n");
 		exit(1);
-	}
-	else
+	} else
 		fprintf(stderr, "done\n");
 
 	mymtop.mt_count=1;
@@ -448,9 +558,12 @@ void load_next(fd)
 void parse_opts(int argc, char* argv[])
 {
 	int c, long_index;
-	while((c = getopt_long(argc, argv, OPTSTRING, longopts,
+	while ((c = getopt_long(argc, argv, OPTSTRING, longopts,
 			       &long_index)) != -1) {
 		switch (c) {
+                        case 'd':
+                                option_d_set = 1;
+				break;
 			case 'a':
 				option_a_set = 1;
 				break;
@@ -465,7 +578,8 @@ void parse_opts(int argc, char* argv[])
 				printf("%s\n", copyright_notice);
 				exit(0);
 			default:
-				printf(usage_note);
+				fprintf(stderr, "Try 'zgetdump --help' for more"
+						" information.\n");
 				exit(1);
 		}
 	}
@@ -473,7 +587,8 @@ void parse_opts(int argc, char* argv[])
 	/* check if -a and -i options are used correctly and check */
 	/* if devicename has been specified                        */
 
-	if((option_a_set && !option_i_set) || (optind != argc-1)){
+	if ((option_a_set && !option_i_set) || (optind != argc-1)
+            || (option_d_set && (option_i_set || option_a_set))){
 		printf(help_text);
 		exit(1);
 	}
@@ -486,9 +601,59 @@ int main(int argc, char *argv[])
 	uint64_t cur_time;
 	int fd = -1;
 	int d_type;
+	int version, dumper_arch, rc;
 
+	rc = 0;
 	parse_opts(argc, argv);
 
+	if (option_d_set) {
+	        if (check_device(device_name)) {
+			rc = 1;
+			goto out;
+		}
+        	fd = open(device_name, O_RDONLY);
+        	if (fd == -1) {
+                	fprintf(stderr, "Cannot open device '%s'. \n", device_name);
+                	perror("");
+			rc = 1;
+			goto out;
+        	}
+
+        	rc = check_for_fba_device(fd, &version, &dumper_arch);
+		if (rc != 0)
+			goto out;	
+		if (version >= 0)
+			goto is_dump_device;
+		else
+               		rc = check_for_eckd_device(fd, &version, &dumper_arch);
+
+        	if (rc != 0)
+			goto out;
+		if (version >= 0)
+			goto is_dump_device;
+
+		fprintf(stderr, "'%s' is no dump device. \n", device_name);
+		rc = 1;
+		goto out;
+
+is_dump_device:
+        	if (version > 0) {
+                	if (dumper_arch == ARCH_S390) {
+                        	fprintf(stderr, "'%s' is Version %i s390 (ESA) dump "
+                                	"device. \n", device_name, version);
+                        	if (check_kernel_mode()) {
+					rc = 1;
+					goto out;
+				}
+                	} else
+                        	fprintf(stderr, "'%s' is Version %i s390x (ESAME) "
+                                	"dump device. \n", device_name, version);
+        	} else
+                	fprintf(stderr, "'%s' is Version 0 dump device. \n",
+                        	device_name);
+		goto out; /* do not consider any other options */
+	}
+
 	if (!option_i_set){		/* copy the dump to stdout */
 		fd = open_dump(device_name);
 		d_type = dev_type(fd);
@@ -499,7 +664,7 @@ int main(int argc, char *argv[])
 		/*	now get_dump returns 1 for all	*/
 		/*	except the last tape of a multi-volume dump */
 
-		while (get_dump(fd,d_type) == 1){
+		while (get_dump(fd,d_type) == 1) {
 			fprintf(stderr, "\nWaiting for next volume to be loaded... ");
 			load_next(fd);
 			get_header(fd,d_type);
@@ -511,23 +676,24 @@ int main(int argc, char *argv[])
 		if (d_type == IS_DASD)
 			lseek(fd,header.dh_header_size + header.dh_memory_size,SEEK_SET);
 
-		if (dump_end_times(fd) == 0){
+		if (dump_end_times(fd) == 0) {
 			ssize_t rc;
 			rc = write(STDOUT_FILENO,&end_marker,sizeof(end_marker));
-			if(rc == -1){
+			if (rc == -1){
 				perror("\nwrite failed");
-				exit(1);
+				rc = 1;
+				goto out;
 			}
-			if(rc < sizeof(end_marker)) {
-				fprintf(stderr,"\nwrite failed: No space left on device\n");
-				exit(1);
+			if (rc < sizeof(end_marker)) {
+				fprintf(stderr,"write failed: No space left on device\n");
+				rc = 1;
+				goto out;
 			}
 			fprintf(stderr, "\nDump End Marker found: this dump is valid.\n");
-		}
-		else
+		} else
 			fprintf(stderr, "\nThis dump is NOT valid.\n");
 	}
-	if (option_i_set && !option_a_set){		/* "-i" option */
+	if (option_i_set && !option_a_set) {		/* "-i" option */
 		fprintf(stderr, "\n> \"zgetdump -i\" checks if a dump on either\n");
 		fprintf(stderr, "> a dasd volume or single tape is valid.\n");
 		fprintf(stderr, "> If the tape is part of a multi-volume tape dump,\n");
@@ -537,87 +703,85 @@ int main(int argc, char *argv[])
 		get_header(fd,d_type);
 		if (d_type == IS_DASD)
 			lseek(fd,header.dh_header_size + header.dh_memory_size,SEEK_SET);
-		else{
+		else {
 			fprintf(stderr, "Checking if the dump is valid - this might take a while...\n");
 			tape_forwards(fd);
 		}
-		if (dump_end_times(fd) == 0){
+		if (dump_end_times(fd) == 0) {
 			fprintf(stderr, "Dump End Marker found: ");
 			if (header.dh_volnr != 0)
 				fprintf(stderr, "this is a valid part of a dump.\n\n");
 			else
 				fprintf(stderr, "this dump is valid.\n\n");
-			exit(0);
-		}
-		else if (d_type == IS_DASD){
+			goto out;
+		} else if (d_type == IS_DASD) {
 			fprintf(stderr, "Dump End Marker not found: this dump is NOT valid.\n\n");
-			exit(1);
-		}
-		else
+			rc = 1;
+			goto out;
+		} else
 			fprintf(stderr, "Checking for End of Volume...\n");
-		if (vol_end(fd) != 0){
+		if (vol_end(fd) != 0) {
 			fprintf(stderr, "End of Volume not found: This dump is NOT valid.\n\n");
-			exit(1);
-		}
-		else {
+			rc = 1;
+			goto out;
+		} else {
 			fprintf(stderr, "Reached End of Volume %i of a multi-volume tape dump.\n",header.dh_volnr);
 			fprintf(stderr, "This part of the dump is valid.\n\n");
-			exit(0);
+			goto out;
 		}
 	}
 
-	if (option_i_set && option_a_set){	/* "-i -a" option */ 
+	if (option_i_set && option_a_set) {	/* "-i -a" option */ 
 		fprintf(stderr, "\n> \"zgetdump -i -a\" checks if a multi-volume tape dump is valid.\n");
 		fprintf(stderr, "> Please make sure that all volumes are loaded in sequence.\n");
 		fd = open_dump(device_name);
 		d_type = dev_type(fd);
-		if (d_type == IS_DASD){
+		if (d_type == IS_DASD) {
 			fprintf(stderr, "\"-i -a\" is used for validation of multi-volume tape dumps.\n\n");
-			exit(1);
+			rc = 1;
+			goto out;
 		}
 		get_header(fd,d_type);
 		cur_volnr = header.dh_volnr;
 		cur_time = header.dh_tod;
 		fprintf(stderr, "\nChecking if the dump is valid - this might take a while...\n");
 		tape_forwards(fd);
-		if (dump_end_times(fd) == 0){
+		if (dump_end_times(fd) == 0) {
 			fprintf(stderr, "Dump End Marker found: this dump is valid.\n\n");
-			exit(0);
-		}
-		else if (vol_end(fd) != 0){
+			goto out;
+		} else if (vol_end(fd) != 0) {
 			fprintf(stderr, "End of Volume not found: This dump is NOT valid.\n\n");
-			exit(1);
+			rc = 1;
+			goto out;
 		}
-		while (vol_end(fd) == 0){
+		while (vol_end(fd) == 0) {
 			cur_volnr += 1;
 			fprintf(stderr, "Reached End of Volume %i.\n", header.dh_volnr);
 			fprintf(stderr, "Waiting for Volume %i to be loaded... ",cur_volnr);
 			load_next(fd);
 			get_header(fd,0);
-			if (header.dh_volnr != cur_volnr){
+			if (header.dh_volnr != cur_volnr) {
 				fprintf(stderr, "This is not Volume %i\n", cur_volnr);
-				exit(1);
-			}
-			else if (header.dh_tod != cur_time){
+				rc = 1;
+				goto out;
+			} else if (header.dh_tod != cur_time) {
 				fprintf(stderr, "Time stamp of this volume does not match the previous one.\n");
-				exit(1);
+				rc = 1;
+				goto out;
 			}
 			tape_forwards(fd);
-			if (dump_end_times(fd) == 0){
+			if (dump_end_times(fd) == 0) {
 				fprintf(stderr, "Dump End found: This dump is valid.\n\n");
-				exit(0);
-			}
-			else if (vol_end(fd) != 0){
+				goto out;
+			} else if (vol_end(fd) != 0) {
 				fprintf(stderr, "End of Volume not found: This dump is NOT valid.\n\n");
-				exit(1);
+				rc = 1;
+				goto out;
 			}
 		}
-
 	}
-
-	if(fd != -1)
+out:
+	if (fd != -1)
 		close(fd);
-	return(0);
+	return(rc);
 }
-
-
