@@ -4,8 +4,8 @@
  *  Provides functionality to dump memory content and register sets
  *  to a dump device. The written dump can be analyzed afterwards
  *  with the dump analysis tool lcrash.
- *  
- *    Copyright (C) 2003-2005 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ *
+ *    Copyright IBM Corp. 2003, 2006.
  *    Author(s): Michael Holzheu <holzheu@de.ibm.com>
  */
 
@@ -26,56 +26,18 @@
 #include <asm/debug.h>
 #include "dump.h"
 
-/*
- * Test parameter list
- */
-
-#ifdef CONFIG_DUMP_TEST
-
-struct {
-        struct ipl_parameter_list {
-                int  length;
-                int  version;
-        } ipl_parameter_list __attribute__((packed));
-        char xml_sample[];
-} ipl_parameter __attribute__((aligned(8)))
-= {{8,0}, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"\
-"<eServer_ipl_script version=\"1.0\">\n"\
-"<type>dump</type>\n"\
-"<ipl_control_section id=\"first_ipl\">\n"\
-"<ipl_platform_loader>\n"\
-"       <fcp_ipl>\n"\
-"            <devno> 0x5c00 </devno>\n"\
-"            <wwpn> 0x5005076300cf9104 </wwpn>\n"\
-"            <lun> 0x5280000000000000 </lun>\n"\
-"            <boot_program_selector> 1 </boot_program_selector>\n"\
-"            <br_lba> 0 </br_lba>\n"\
-"        </fcp_ipl>\n"\
-"</ipl_platform_loader>\n"\
-"<system_control_program>\n"\
-"<parameter_string>\n"\
-"asdfdasf\n"\
-"</parameter_string>\n"\
-"</system_control_program>\n"\
-"</ipl_control_section>\n"\
-"</eServer_ipl_script>\n"\
-"\0"
-};
-
-#endif
-
 /*******************************************************************
  * defines 
  *******************************************************************/
 
-#define DUMP_MEM_SIZE_MB          32UL 
+#define DUMP_MEM_SIZE_MB 32UL
 
 #define DUMP_SAVE_AREA_BASE_ESAME 4608
 #define DUMP_SAVE_AREA_BASE_ESA   212
 
-#define DUMP_LC_ARCH_MODE_ADDR	  0xa3  /* dec. 163: Address of arch id tag */
-#define DUMP_LC_ARCH_MODE_ESAME   1	/* esame mode id tag */
-#define DUMP_LC_ARCH_MODE_ESA	  0	/* esa mode id tag */
+#define DUMP_LC_ARCH_MODE_ADDR  0xa3  /* dec. 163: Address of arch id tag */
+#define DUMP_LC_ARCH_MODE_ESAME 1     /* esame mode id tag */
+#define DUMP_LC_ARCH_MODE_ESA   0     /* esa mode id tag */
 
 #ifdef __s390x__
 #define LOWCORE_SIZE 0x2000
@@ -83,7 +45,7 @@ struct {
 #define LOWCORE_SIZE 0x1000
 #endif
 
-#define DEBUG_LEVEL_DEFAULT       2
+#define DEBUG_LEVEL_DEFAULT 2
 
 #define DUMP_MAX_CPUS 1024
 
@@ -92,7 +54,8 @@ struct {
 
 #define STIDP(x) asm volatile ("STIDP 0(%0)" : : "a" (&(x)) : "memory" ,"cc")
 
-#define DUMP_PRINT_TRACE(x...) if(dump.debug_level > 3) {printk( KERN_ALERT "K_TRACE: " x );}
+#define DUMP_PRINT_TRACE(x...) if(dump.debug_level > 3) \
+			{printk( KERN_ALERT "K_TRACE: " x );}
 #define DUMP_PRINT_ERR(x...)  printk( KERN_ALERT "K_ERROR: " x )
 #define DUMP_PRINT_WARN(x...) printk( KERN_ALERT "K_WARNING: " x )
 #define DUMP_PRINT(x...)      printk( KERN_ALERT x )
@@ -140,10 +103,10 @@ typedef union {
 /* dump arch info */
 
 typedef struct _dump_arch {
-	dump_arch_id_t   arch;	         /* arch id */
-	unsigned long    save_area_base; /* save area base rel. to pref. page */
-	__u32	         save_area_size; /* size fo save area */
-	dump_cpu_info_t* cpu_info;       /* cpu-info array with registers */
+	dump_arch_id_t	 arch;		 /* arch id */
+	unsigned long	 save_area_base; /* save area base rel. to pref. page */
+	__u32		 save_area_size; /* size fo save area */
+	dump_cpu_info_t* cpu_info;	 /* cpu-info array with registers */
 } dump_arch_t;
 
 /*******************************************************************
@@ -172,7 +135,7 @@ static int sdias_memcpy(char* target, char* src, int count);
  *******************************************************************/
 
 extern unsigned long memory_size;   /* Mem size */
-extern char          *ldipl_xml;    /* xml parameter passed by ldipl */
+extern void          *ldipl_parm;   /* parameter block passed by ldipl */
 extern volatile int __cpu_logical_map[];
 
 /*******************************************************************
@@ -202,7 +165,9 @@ static struct {
 	debug_info_t            *dbf;                 /* Debug feature handle */
 	int                     error_code;           /* error code of dumper. can be obtained from user space with ioctl */
 } dump;
- 
+
+struct ipl_block_fcp *fcp_data;
+
 /*******************************************************************
  * functions
  *******************************************************************/
@@ -215,7 +180,7 @@ static int __init dump_debug(char *str)
 {
 	get_option(&str, &console_loglevel);
 	dump.debug_level=console_loglevel;
-        return 1;
+	return 1;
 }
  
 __setup("dump_debug=", dump_debug);
@@ -267,17 +232,17 @@ dump_sigp(__u16 cpu_addr, sigp_order_code order_code)
 extern __inline__ sigp_ccode
 dump_sigp(__u16 cpu_addr, sigp_order_code order_code)
 {
-        sigp_ccode ccode;
- 
-        __asm__ __volatile__(
-                "    sr     1,1\n"        /* parameter=0 in gpr 1 */
-                "    sigp   1,%1,0(%2)\n"
-                "    ipm    %0\n"
-                "    srl    %0,28"
-                : "=d" (ccode)
-                : "d" (dump.cpu_logical_map[cpu_addr]), "a" (order_code)
-                : "cc" , "memory", "1" );
-        return ccode;
+	sigp_ccode ccode;
+
+	__asm__ __volatile__(
+		"    sr     1,1\n"        /* parameter=0 in gpr 1 */
+		"    sigp   1,%1,0(%2)\n"
+		"    ipm    %0\n"
+		"    srl    %0,28"
+		: "=d" (ccode)
+		: "d" (dump.cpu_logical_map[cpu_addr]), "a" (order_code)
+		: "cc" , "memory", "1" );
+	return ccode;
 }
 
 #endif
@@ -309,17 +274,17 @@ dump_sigp_direct(__u16 cpu_addr, sigp_order_code order_code)
 extern __inline__ sigp_ccode
 dump_sigp_direct(__u16 cpu_addr, sigp_order_code order_code)
 {
-        sigp_ccode ccode;
- 
-        __asm__ __volatile__(
-                "    sr     1,1\n"        /* parameter=0 in gpr 1 */
-                "    sigp   1,%1,0(%2)\n"
-                "    ipm    %0\n"
-                "    srl    %0,28"
-                : "=d" (ccode)
-                : "a" (cpu_addr), "a" (order_code)
-                : "cc" , "memory", "1" );
-        return ccode;
+	sigp_ccode ccode;
+
+	__asm__ __volatile__(
+		"    sr     1,1\n"        /* parameter=0 in gpr 1 */
+		"    sigp   1,%1,0(%2)\n"
+		"    ipm    %0\n"
+		"    srl    %0,28"
+		: "=d" (ccode)
+		: "a" (cpu_addr), "a" (order_code)
+		: "cc" , "memory", "1" );
+	return ccode;
 }
 
 #endif
@@ -333,10 +298,9 @@ dump_smp_count_cpus(void)
 	int curr_cpu;
 	int num_cpus = 1;
 	int rc;
-        __u16 boot_cpu_addr = __cpu_logical_map[0]; /* physical number of */
+
+	__u16 boot_cpu_addr = __cpu_logical_map[0]; /* physical number of */
                                                     /* cpu */
-
-
 	dump.cpu_logical_map[0] = boot_cpu_addr;
 	for (curr_cpu = 0; curr_cpu <= 65535; curr_cpu++) {
 		if ((__u16) curr_cpu == boot_cpu_addr ){
@@ -584,17 +548,28 @@ error:
 	return NULL;
 }
 
-void setup_dump(char* cmdline, unsigned short *init_devno)
+void setup_dump_devnos(char *cmdline, unsigned int init_devno,
+		       unsigned int cons_devno)
+{
+	char str[100] = {0};
+	if (cons_devno == -1)
+		sprintf(str," cio_ignore=all,!0.0.%04x", init_devno);
+	else
+		sprintf(str," cio_ignore=all,!0.0.%04x,!0.0.%04x", init_devno,
+			cons_devno);
+	strcat(cmdline, str);
+}
+
+void setup_dump_base(void)
 {
 	char str[100] = {0};
 #ifdef __s390x__
-        printk("System Dumper s390x starting...\n");
+	printk("System Dumper s390x starting...\n");
 #else
 	printk("System Dumper s390 starting...\n");
 #endif
-	sprintf(str," root=/dev/ram0 rw mem=%liM maxcpus=1 cio_ignore=all,!0.0.%04x",
-                DUMP_MEM_SIZE_MB, *init_devno);
-	strcat(cmdline,str);
+	sprintf(str," root=/dev/ram0 rw mem=%liM maxcpus=1", DUMP_MEM_SIZE_MB);
+	strcat(COMMAND_LINE, str);
 	console_loglevel = DEBUG_LEVEL_DEFAULT;
 	dump.debug_level = DEBUG_LEVEL_DEFAULT;
 }
@@ -610,15 +585,20 @@ dump_init(void)
 	long hsa_nr_of_blocks;
 	int rc = 0;
 
-        dump.dbf = debug_register("dump", 1, 1, 8);
+	fcp_data = &(((struct ipl_parameter_block *)ldipl_parm)->fcp);
+	DUMP_PRINT_TRACE("LEN  : %x\n",fcp_data->length);
+	DUMP_PRINT_TRACE("DEVNO: %x\n",fcp_data->devno);
+	DUMP_PRINT_TRACE("WWPN : %lx\n",fcp_data->wwpn);
+	DUMP_PRINT_TRACE("LUN  : %lx\n",fcp_data->lun);
+
+	dump.dbf = debug_register("dump", 1, 1, 8);
 	if(dump.dbf)
-        	debug_register_view(dump.dbf, &debug_hex_ascii_view);
-        DUMP_PRINT_TRACE("DEBUGAREA: %p\n",dump.dbf->areas[0]);
+		debug_register_view(dump.dbf, &debug_hex_ascii_view);
+	DUMP_PRINT_TRACE("DEBUGAREA: %p\n",dump.dbf->areas[0]);
 
 	debug_text_event(dump.dbf, 1, "startdbf");
 
 	DUMP_PRINT_TRACE("DUMP init\n");
-	DUMP_PRINT_TRACE("xml: %s\n",ldipl_xml);
 
 	if(sdias_init()){
 		DUMP_PRINT_ERR("could initialize sclp\n");
@@ -814,7 +794,6 @@ zcore_init(void)
 		DUMP_PRINT_ERR("unable to get major %d for memory devs\n",
 			MEM_MAJOR);
 		rc = -1; goto out;
-
 	}
 out:
 	return rc;
@@ -978,7 +957,6 @@ zcore_ioctl(struct inode *inode, struct file *filp,
 	    unsigned int cmd, unsigned long arg)
 {
 	int rc = 0;
-	int xml_size = strlen(ldipl_xml);
 	int hsa_size = (int)dump.sa_mem_size;
 	DUMP_PRINT_TRACE("ioctl: %x\n",cmd);
 	switch(cmd){
@@ -989,15 +967,9 @@ zcore_ioctl(struct inode *inode, struct file *filp,
 				rc = -EFAULT;
 			}
 			break;
-		case ZCORE_IOCTL_XMLSIZE:
-			DUMP_PRINT_TRACE("xml size: %i\n",xml_size);
-			if(copy_to_user ((char *) arg, &xml_size, sizeof(int))){
-				DUMP_PRINT_ERR("ZCORE_IOCTL_XMLSIZE: failed\n");
-				rc = -EFAULT;
-			}
-			break;
-		case ZCORE_IOCTL_GETXML:
-			if(copy_to_user ((char *) arg, ldipl_xml, xml_size)){
+		case ZCORE_IOCTL_GET_PARMS:
+			if(copy_to_user ((char *) arg, fcp_data,
+				sizeof(*fcp_data))){
 				DUMP_PRINT_ERR("ZCORE_IOCTL_GETXML: faled\n");
 				rc = -EFAULT;
 			}
@@ -1026,9 +998,9 @@ zcore_ioctl(struct inode *inode, struct file *filp,
 			r1 = 0x0;
 			r2 = 0x2;
 			asm volatile ("   diag  %0,%1,0x308\n"
-                      		: 
-                                : "d" (r1), "d" (r2)
-                      		: "cc"
+				: 
+				: "d" (r1), "d" (r2)
+				: "cc"
                         );
 #endif
 			break;
@@ -1273,9 +1245,9 @@ sdias_copy_blocks(void* target,int start_blk, int nr_blks)
 	int rc = 0;
 
 	memset(&sccb_cb,0,sizeof(sccb_cb));
- 
+
 	sccb_cb.header.length  = sizeof(sccb_cb);
- 
+
 	sccb_cb.sdias_evbuf.header.length	= sizeof(struct sdias_evbuf);
 	sccb_cb.sdias_evbuf.header.type		= SDIAS_OP_CODE;
 	sccb_cb.sdias_evbuf.header.flags 	= 0;
@@ -1294,12 +1266,11 @@ sdias_copy_blocks(void* target,int start_blk, int nr_blks)
 	sccb_cb.sdias_evbuf.lbn			= 0;
 	sccb_cb.sdias_evbuf.dbs			= 1;
 
- 
 	sdias_request.sccb     = &sccb_cb;
 	sdias_request.command  = SCLP_CMDW_WRITEDATA;
 	sdias_request.status   = SCLP_REQ_FILLED;
 	sdias_request.callback = sdias_callback;
- 
+
 	if(dump_sclp_send(&sdias_request) != 0){
 		DUMP_PRINT_ERR("sclp_send failed\n");
 		rc = -1;
@@ -1385,4 +1356,3 @@ out:
 
 late_initcall(dump_init);
 module_exit(dump_exit);
-
