@@ -1,12 +1,12 @@
 /******************************************************************************/
 /*  zfcp_dumper.c                                                             */
 /*                                                                            */
-/*    Copyright (C) 2003-2005 IBM Deutschland Entwicklung GmbH,               */
-/*                  IBM Corporation                                           */
+/*    Copyright IBM Corp. 2003, 2006.                                     */
 /*    Author(s): Michael Holzheu <holzheu@de.ibm.com>                         */
 /*               Andreas Herrmann <aherrman@de.ibm.com>                       */
 /******************************************************************************/
 
+#include <asm/types.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
@@ -28,8 +28,14 @@
 #include <ctype.h>
 
 #include "zfcp_dumper.h"
-#include "evaluate_xml.h"
 #include "../kernel/dump.h"
+#include "zt_common.h"
+
+#ifdef __s390x__
+#define FMT64 "l"
+#else
+#define FMT64 "ll"
+#endif
 
 #ifndef MIN
 #define MIN(x,y) ((x) < (y) ? (x) : (y))
@@ -168,7 +174,7 @@ typedef struct dump_header_s {
         struct {uint64_t tv_sec;
                 uint64_t tv_usec;
         } time; /* the time of the system crash */
- 
+
         /* the NEW utsname (uname) information -- in character form */
         /* we do this so we don't have to include utsname.h         */
         /* plus it helps us be more architecture independent        */
@@ -178,13 +184,13 @@ typedef struct dump_header_s {
         char utsname_version[UTS_LEN];
         char utsname_machine[UTS_LEN];
         char utsname_domainname[UTS_LEN];
- 
+
         uint64_t current_task;  
         uint32_t dump_compress; /* compression type used in this dump */
         uint32_t dump_flags;    /* any additional flags */
         uint32_t dump_device;   /* any additional flags */
 } __attribute__((packed)) dump_header_t;
- 
+
 /* This is the header used by zcore
  */
 typedef struct dump_header_s390sa_s {
@@ -271,20 +277,20 @@ static int parse_parmline(void){
 
 	fh = open(PROC_CMDLINE,O_RDONLY);
 	if(fh == -1){
-                PRINT_PERR("open %s failed\n",PROC_CMDLINE);
-                rc = -1;goto out;
-        }
+		PRINT_PERR("open %s failed\n",PROC_CMDLINE);
+		rc = -1;goto out;
+	}
 	if((count = read(fh,g.parmline,CMDLINE_MAX_LEN)) == -1){
 		PRINT_PERR("read %s failed\n", PROC_CMDLINE);
 		rc = -1;goto out;
 	}
 	g.parmline[count-1]='\0'; /* remove \n */
 
-        token = strtok(g.parmline, " \t\n");
-        while(token != NULL){
-                parms[i] = token;
-                token = strtok(NULL," \t\n");
-                i++;
+	token = strtok(g.parmline, " \t\n");
+	while(token != NULL){
+		parms[i] = token;
+		token = strtok(NULL," \t\n");
+		i++;
 		if(i >= PARM_MAX){
 			PRINT_WARN("THIS SHOULD NOT HAPPEN: More than %i "
 				"kernel parmameters specified\n",PARM_MAX);
@@ -292,17 +298,17 @@ static int parse_parmline(void){
 				"parameters will not be considered!\n");
 			break;
 		}
-        }
-        for(j = 0; j < i; j++){
-                token = strtok(parms[j],"=");
-                if(token == NULL){
+	}
+	for(j = 0; j < i; j++){
+		token = strtok(parms[j],"=");
+		if(token == NULL){
 			/* No '=' parameter, just skip it */
-                        continue;
+			continue;
 
 		/* Dump Dir */
 
-                } else if(strcmp(token, PARM_DUMP_DIR) == 0){
-                        g.parm_dump_dir = strtok(NULL,"=");
+		} else if(strcmp(token, PARM_DUMP_DIR) == 0){
+			g.parm_dump_dir = strtok(NULL,"=");
 			if(g.parm_dump_dir == NULL){
 				PRINT_WARN("No value for '%s' parameter "
 					"specified\n", PARM_DUMP_DIR);
@@ -313,8 +319,8 @@ static int parse_parmline(void){
 
 		/* Dump Partition */
 
-                } else if(strcmp(token, PARM_DUMP_PART) == 0){
-                        g.parm_dump_part = strtok(NULL,"=");
+		} else if(strcmp(token, PARM_DUMP_PART) == 0){
+			g.parm_dump_part = strtok(NULL,"=");
 			if(g.parm_dump_part == NULL){
 				PRINT_ERR("No value for '%s' parameter "
 					"specified\n", PARM_DUMP_PART);
@@ -324,7 +330,7 @@ static int parse_parmline(void){
 
 		/* Dump mem */
 
-                } else if(strcmp(token, PARM_DUMP_MEM) == 0){
+		} else if(strcmp(token, PARM_DUMP_MEM) == 0){
 			char* mem_str = strtok(NULL,"=");
 			if(mem_str == NULL){
 				PRINT_ERR("No value for '%s' parameter "
@@ -336,7 +342,7 @@ static int parse_parmline(void){
 
 		/* Dump Compression */
 
-                } else if(strcmp(token, PARM_DUMP_COMPRESS) == 0){
+		} else if(strcmp(token, PARM_DUMP_COMPRESS) == 0){
 			g.parm_dump_compress = strtok(NULL,"=");
 			if(g.parm_dump_compress == NULL){
 				PRINT_WARN("No value for '%s' parameter "
@@ -346,7 +352,7 @@ static int parse_parmline(void){
 				g.parm_dump_compress = PARM_DUMP_COMPRESS_DFLT;
 			} else if((strcmp(g.parm_dump_compress,
 					PARM_DUMP_COMPRESS_GZIP) != 0) &&
-           		          (strcmp(g.parm_dump_compress,
+					(strcmp(g.parm_dump_compress,
 					PARM_DUMP_COMPRESS_NONE) != 0)){
 				PRINT_WARN("Unknown dump compression '%s' "
 					"specified!\n",g.parm_dump_compress);
@@ -401,7 +407,7 @@ static int parse_parmline(void){
 		}
         }
 	PRINT_TRACE("dump dir  : %s\n",g.parm_dump_dir);
-        PRINT_TRACE("dump part : %s\n",g.parm_dump_part);
+	PRINT_TRACE("dump part : %s\n",g.parm_dump_part);
 	PRINT_TRACE("dump comp : %s\n",g.parm_dump_compress);
 	PRINT_TRACE("dump debug: %d\n",g.parm_dump_debug); 
 	PRINT_TRACE("dump mem:   %llx\n",g.parm_dump_mem); 
@@ -462,43 +468,31 @@ out:
 }
 
 /*
- * get_xml_string()
+ * get_fcp_info()
  * 
- * Read LDIPL xml string from /dev/zcore
- * Return: pointer to newly allocated xml-string - ok
- *         NULL                                  - error 
+ * Read fcp info from /dev/zcore
+ * Return: 0  - ok
+ *         -1 - error
  */
-char* get_xml_string(void)
+int get_fcp_info(struct ipl_block_fcp *fcp_info)
 {
-	int fh = -1;
-	int xml_len;
-	char* xml_string = NULL;
+	int fh = -1, rc = 0;
 
 	fh = open(DEV_ZCORE,O_RDWR); 
 	if(fh == -1){
 		PRINT_PERR("open %s failed", DEV_ZCORE);
+		rc = -1;
 		goto out;
 	}
-	if(ioctl(fh, ZCORE_IOCTL_XMLSIZE, &xml_len) == -1){
-		PRINT_PERR("ioctl 'get xml size' failed");
+	if(ioctl(fh, ZCORE_IOCTL_GET_PARMS, fcp_info) == -1){
+		PRINT_PERR("ioctl 'get fcp parms' failed");
+		rc = -1;
 		goto out;
 	}
-	xml_string = (char*)calloc(1,xml_len + 1);
-	if(!xml_string){
-		PRINT_PERR("malloc failed for xml string");
-		goto out;
-	}
-	if(ioctl(fh, ZCORE_IOCTL_GETXML,xml_string) == -1){
-		free(xml_string);
-		xml_string=NULL;
-		PRINT_PERR("ioctl 'get xml' failed");
-		goto out;
-	}
-	PRINT_TRACE("got xml: %s\n",xml_string);
 out:
 	if(fh != -1)
 		close(fh);
-	return xml_string;
+	return rc;
 }
 
 /*
@@ -533,11 +527,11 @@ write_to_file(const char* fcp_file, const char* command)
 {
 	int rc = 0, fh = 0;
 
-        fh = open(fcp_file,O_WRONLY);
-        if(fh == -1){
-                PRINT_PERR("Could not open %s",fcp_file);
-                rc = -1; goto out;
-        }
+	fh = open(fcp_file,O_WRONLY);
+	if(fh == -1){
+		PRINT_PERR("Could not open %s",fcp_file);
+		rc = -1; goto out;
+	}
 	if(write(fh, command, strlen(command)) != strlen(command)){
 		PRINT_PERR("Write to %s failed",fcp_file);
 		rc = -1; goto out;
@@ -556,7 +550,7 @@ out:
  * Return:    0 - ok
  *         != 0 - error
  */
-int enable_zfcp_device(fcp_info_t* fcp_info)
+int enable_zfcp_device(struct ipl_block_fcp *fcp_info)
 {
 	int fh = -1, fh_check;
 	int rc = 0;
@@ -574,7 +568,7 @@ int enable_zfcp_device(fcp_info_t* fcp_info)
 		fcp_info->devno);
 	if(write_to_file(fcp_file, command_string))
 		return -1;
-	sprintf(command_string, "0x%016llx\n",fcp_info->fcp_lun);
+	sprintf(command_string, "0x%016llx\n",fcp_info->lun);
 	sprintf(fcp_file,"/sys/bus/ccw/drivers/zfcp/0.0.%04x/0x%016llx/"
 		"unit_add",fcp_info->devno,fcp_info->wwpn);
 	if(write_to_file(fcp_file, command_string))
@@ -614,7 +608,7 @@ int mount_dump_device(void)
 	if(mount(DEV_SCSI, DUMP_MOUNT_POINT, "ext2", 0, NULL) != 0){
 		PRINT_PERR("mount failed\n");
 		rc = -1; goto out;
-        }
+	}
 out:
 	return rc;
 }
@@ -629,10 +623,10 @@ out:
 int umount_dump_device(void)
 {
 	int rc = 0;
-        if(umount(DUMP_MOUNT_POINT) != 0){
-                PRINT_PERR("umount failed");
-                rc = -1; goto out;
-        }
+	if(umount(DUMP_MOUNT_POINT) != 0){
+		PRINT_PERR("umount failed");
+		rc = -1; goto out;
+	}
 out:
 	return rc;
 }
@@ -654,11 +648,11 @@ static void release_hsa(void)
 	fflush(stdout);
 	fflush(stderr);
 	fh = open(DEV_ZCORE,O_RDWR);
-        if(fh == -1){
+	if(fh == -1){
 		PRINT_PERR("open %s failed", DEV_ZCORE);
 		goto out;
 	}
-        if(ioctl(fh, ZCORE_IOCTL_RELEASE_HSA,NULL) == -1){
+	if(ioctl(fh, ZCORE_IOCTL_RELEASE_HSA,NULL) == -1){
 		PRINT_PERR("ioctl 'release hsa' failed");
 		goto out;
 	}
@@ -677,8 +671,7 @@ out:
 int main(int argc, char* argv[])
 {
 	int rc = 0;
-	fcp_info_t fcp_info;
-	char* xml_string;
+	struct ipl_block_fcp fcp_info;
 
 #ifdef __s390x__
 	PRINT("Linux for zSeries System Dumper starting\n");
@@ -691,16 +684,16 @@ int main(int argc, char* argv[])
 		PRINT_ERR("Init Signals failed!\n");
 		rc = 1; goto out;
 	}
-        if(mount("proc","/proc","proc", 0, NULL)){
-                PRINT_PERR("Unable to mount proc\n");
+	if(mount("proc","/proc","proc", 0, NULL)){
+		PRINT_PERR("Unable to mount proc\n");
 		rc = 1; goto out;
 	}
 	if(dump_tune_vm()){
 		PRINT_PERR("Unable to set VM settings\n");
 		rc = 1; goto out;
 	}
-        if(mount("sysfs","/sys","sysfs", 0, NULL)){
-                PRINT_PERR("Unable to mount sysfs\n");
+	if(mount("sysfs","/sys","sysfs", 0, NULL)){
+		PRINT_PERR("Unable to mount sysfs\n");
 		rc = 1; goto out;
 	}
 	if(parse_parmline()){
@@ -723,14 +716,8 @@ int main(int argc, char* argv[])
 		PRINT_ERR("Check if your Microcode is up to date!\n");
 		rc = 1; goto out;
 	}
-	xml_string = get_xml_string();
-	if(xml_string == NULL){
-		PRINT_ERR("Could not get XML data\n");
-		rc = 1; goto out;
-	}
-	if(get_fcp_info(xml_string,&fcp_info)){
-		PRINT_ERR("Could not parse XML data:\n");
-		PRINT_ERR("%s\n",xml_string);
+	if(get_fcp_info(&fcp_info)){
+		PRINT_ERR("Could not get fcp data:\n");
 		rc = 1; goto out;
 	}
 
@@ -740,14 +727,13 @@ int main(int argc, char* argv[])
 	PRINT("================\n");
 	PRINT("devno    : %x\n",fcp_info.devno);
 	PRINT("wwpn     : %016llx\n",fcp_info.wwpn);
-	PRINT("lun      : %016llx\n",fcp_info.fcp_lun);
-	PRINT("conf     : %i\n",fcp_info.configuration);
-	PRINT("type     : %s\n",fcp_info.type);
+	PRINT("lun      : %016llx\n",fcp_info.lun);
+	PRINT("conf     : %i\n",fcp_info.bootprog);
 	PRINT("partition: %s\n",g.parm_dump_part);
 	PRINT("directory: %s\n",g.parm_dump_dir);
 	PRINT("compress : %s\n",g.parm_dump_compress);
 
-	if(strcmp(fcp_info.type,"dump")){
+	if(!(fcp_info.type & BOOT_TYPE_DUMP)){
 		PRINT_ERR("IPL type is not dump\n");
 		rc = 1; goto out;
 	}
@@ -787,8 +773,6 @@ out:
 	dump_terminate();
 }
 
-
-
 /*
  * dump_terminate()
  *
@@ -797,7 +781,7 @@ out:
 static void
 dump_terminate(void)
 {
-        release_hsa();
+	release_hsa();
 	sleep(SLEEP_TIME_END); /* give the messages time to be displayed */
 	reboot(LINUX_REBOOT_CMD_POWER_OFF);
 }
@@ -810,13 +794,12 @@ dump_terminate(void)
 static __sighandler_t
 dump_sig_handler(int sig, siginfo_t *sip, void*p)
 {
-        PRINT_ERR("Got signal: %i\n",sig);
-        PRINT_ERR("Dump failed!\n");
+	PRINT_ERR("Got signal: %i\n",sig);
+	PRINT_ERR("Dump failed!\n");
 	dump_terminate();
 	return 0;
 }
 
-
 /*
  * dump_init_sig()
  *
@@ -828,29 +811,29 @@ static int
 dump_init_sig(void)
 {
 	int rc = 0;
-        g.dump_sigact.sa_flags = (SA_NODEFER | SA_SIGINFO | SA_RESETHAND);
-        g.dump_sigact.sa_handler = (__sighandler_t)dump_sig_handler;
-        if (sigemptyset(&g.dump_sigact.sa_mask) < 0) {
+	g.dump_sigact.sa_flags = (SA_NODEFER | SA_SIGINFO | SA_RESETHAND);
+	g.dump_sigact.sa_handler = (__sighandler_t)dump_sig_handler;
+	if (sigemptyset(&g.dump_sigact.sa_mask) < 0) {
 		rc = -1; goto out;
-        }
-        if (sigaction(SIGINT, &g.dump_sigact, NULL) < 0) {
+	}
+	if (sigaction(SIGINT, &g.dump_sigact, NULL) < 0) {
 		rc = -1; goto out;
-        }
-        if (sigaction(SIGTERM, &g.dump_sigact, NULL) < 0) {
+	}
+	if (sigaction(SIGTERM, &g.dump_sigact, NULL) < 0) {
 		rc = -1; goto out;
-        }
-        if (sigaction(SIGPIPE, &g.dump_sigact, NULL) < 0) {
+	}
+	if (sigaction(SIGPIPE, &g.dump_sigact, NULL) < 0) {
 		rc = -1; goto out;
-        }
-        if (sigaction(SIGABRT, &g.dump_sigact, NULL) < 0) {
+	}
+	if (sigaction(SIGABRT, &g.dump_sigact, NULL) < 0) {
 		rc = -1; goto out;
-        }
-        if (sigaction(SIGSEGV, &g.dump_sigact, NULL) < 0) {
+	}
+	if (sigaction(SIGSEGV, &g.dump_sigact, NULL) < 0) {
 		rc = -1; goto out;
-        }
-        if (sigaction(SIGBUS, &g.dump_sigact, NULL) < 0) {
+	}
+	if (sigaction(SIGBUS, &g.dump_sigact, NULL) < 0) {
 		rc = -1; goto out;
-        }
+	}
 out:
 	return rc;
 }
@@ -1009,7 +992,7 @@ erase_oldest_dump(void)
 	}
 	sync();
 	/* Wait in order to give ext3 time to discover that file has been */
-        /* removed.  */
+	/* removed.  */
 	sleep(SLEEP_TIME_ERASE); 
 	PRINT("Dump removed!\n");
 out:
@@ -1068,32 +1051,32 @@ int
 compress_gzip(const unsigned char *old, uint32_t old_size, unsigned char *new,
 		uint32_t new_size)
 {
-        int rc;
-        unsigned long len = old_size;
-        rc = compress(new, &len, old, new_size);
-        switch(rc){
-                case Z_OK:
-                        rc = len;
-                        break;
-                case Z_MEM_ERROR:
-                        PRINT_ERR("Z_MEM_ERROR (not enough memory)!\n");
-                        rc = -1;
-                        break;
-                case Z_BUF_ERROR:
-                        /* In this case the compressed output is bigger than
-			   the uncompressed */
-                        rc = -1;
-                        break;
-                case Z_DATA_ERROR:
-                        PRINT_ERR("Z_DATA_ERROR (input data corrupted)!\n");
-                        rc = -1;
-                        break;
-                default:
-                        PRINT_ERR("Z_UNKNOWN_ERROR (rc 0x%x unknown)!\n",rc);
-                        rc = -1;
-                        break;
-        }
-        return rc;
+	int rc;
+	unsigned long len = old_size;
+	rc = compress(new, &len, old, new_size);
+	switch(rc){
+	case Z_OK:
+		rc = len;
+		break;
+	case Z_MEM_ERROR:
+		PRINT_ERR("Z_MEM_ERROR (not enough memory)!\n");
+		rc = -1;
+		break;
+	case Z_BUF_ERROR:
+		/* In this case the compressed output is bigger than
+		   the uncompressed */
+		rc = -1;
+		break;
+	case Z_DATA_ERROR:
+		PRINT_ERR("Z_DATA_ERROR (input data corrupted)!\n");
+		rc = -1;
+		break;
+	default:
+		PRINT_ERR("Z_UNKNOWN_ERROR (rc 0x%x unknown)!\n",rc);
+		rc = -1;
+		break;
+	}
+	return rc;
 }
 
 /*
@@ -1105,7 +1088,7 @@ int
 compress_none(const unsigned char *old, uint32_t old_size, unsigned char *new,
 	uint32_t new_size)
 {
-        return -1;
+	return -1;
 }
 
 /*
@@ -1118,38 +1101,38 @@ compress_none(const unsigned char *old, uint32_t old_size, unsigned char *new,
 void
 s390sa_to_reg_header(dump_header_s390sa_t* dh_s390sa, dump_header_t* dh)
 {
-        struct timeval     h_time;
- 
-        /* adjust todclock to 1970 */
-        uint64_t tod = dh_s390sa->tod;
-        tod -= 0x8126d60e46000000LL - (0x3c26700LL * 1000000 * 4096);
-        tod >>= 12;
-        h_time.tv_sec  = tod / 1000000;
-        h_time.tv_usec = tod % 1000000;
- 
-        dh->memory_size    = dh_s390sa->memory_size;
-        dh->memory_start   = dh_s390sa->memory_start;
-        dh->memory_end     = dh_s390sa->memory_end;
-        dh->num_dump_pages = dh_s390sa->num_pages;
-        dh->page_size      = dh_s390sa->page_size;
-        dh->dump_level     = dh_s390sa->dump_level;
- 
-        sprintf(dh->panic_string,"zSeries-dump (CPUID = %16"FMT64"x)",
+	struct timeval     h_time;
+
+	/* adjust todclock to 1970 */
+	uint64_t tod = dh_s390sa->tod;
+	tod -= 0x8126d60e46000000LL - (0x3c26700LL * 1000000 * 4096);
+	tod >>= 12;
+	h_time.tv_sec  = tod / 1000000;
+	h_time.tv_usec = tod % 1000000;
+
+	dh->memory_size    = dh_s390sa->memory_size;
+	dh->memory_start   = dh_s390sa->memory_start;
+	dh->memory_end     = dh_s390sa->memory_end;
+	dh->num_dump_pages = dh_s390sa->num_pages;
+	dh->page_size      = dh_s390sa->page_size;
+	dh->dump_level     = dh_s390sa->dump_level;
+
+	sprintf(dh->panic_string,"zSeries-dump (CPUID = %16"FMT64"x)",
 		dh_s390sa->cpu_id);
- 
-        if(dh_s390sa->arch_id == DH_ARCH_ID_S390){
-                strcpy(dh->utsname_machine,"s390");
-        } else if(dh_s390sa->arch_id == DH_ARCH_ID_S390X) {
-                strcpy(dh->utsname_machine,"s390x");
-        } else {
-                strcpy(dh->utsname_machine,"unknown");
-        }
- 
-        dh->magic_number   = DUMP_MAGIC_NUMBER;
-        dh->version        = DUMP_VERSION_NUMBER;
-        dh->header_size    = sizeof(dump_header_t);
-        dh->time.tv_sec    = h_time.tv_sec;
-        dh->time.tv_usec   = h_time.tv_usec;
+
+	if(dh_s390sa->arch_id == DH_ARCH_ID_S390){
+		strcpy(dh->utsname_machine,"s390");
+	} else if(dh_s390sa->arch_id == DH_ARCH_ID_S390X) {
+		strcpy(dh->utsname_machine,"s390x");
+	} else {
+		strcpy(dh->utsname_machine,"unknown");
+	}
+
+	dh->magic_number   = DUMP_MAGIC_NUMBER;
+	dh->version        = DUMP_VERSION_NUMBER;
+	dh->header_size    = sizeof(dump_header_t);
+	dh->time.tv_sec    = h_time.tv_sec;
+	dh->time.tv_usec   = h_time.tv_usec;
 }
 
 /*
@@ -1189,7 +1172,7 @@ static int
 dump_create_s390sa(char* sourcedev, char* dumpdir)
 {
 	struct stat stat_buf;
-        dump_header_t dh;
+	dump_header_t dh;
 	dump_header_s390sa_t s390_dh;
 	compress_fn_t compress_fn;
 	dump_page_t dp;
@@ -1211,7 +1194,7 @@ dump_create_s390sa(char* sourcedev, char* dumpdir)
 			dumpdir);
 		rc = -1; goto out;
 	}
-	
+
 	/* initialize progress time */
 	g.last_progress_time = 0;
 
@@ -1228,32 +1211,31 @@ dump_create_s390sa(char* sourcedev, char* dumpdir)
 		rc = -1; goto out;
 	}
 
-
-        /* make the new filename */
-        sprintf(dump_file_name, "%s/dump.%d", dumpdir, g.dump_nr);
-        if ((fp_dump = open(dump_file_name, O_CREAT|O_RDWR|O_TRUNC,
+	/* make the new filename */
+	sprintf(dump_file_name, "%s/dump.%d", dumpdir, g.dump_nr);
+	if ((fp_dump = open(dump_file_name, O_CREAT|O_RDWR|O_TRUNC,
 		(S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH))) < 0) {
-                        PRINT_ERR("open() of dump file \"%s\" failed!\n",
+			PRINT_ERR("open() of dump file \"%s\" failed!\n",
 				dump_file_name);
 			rc = -1; goto out;
-        }
+	}
 
 	PRINT("dump file: dump.%d\n",g.dump_nr);
-        memset(&dh, 0, sizeof(dh));
+	memset(&dh, 0, sizeof(dh));
 
 	/* get the dump header */
 
-        if (lseek(fp_src, 0, SEEK_SET) < 0) {
-                PRINT_ERR("Cannot lseek() to get the dump header from the "
+	if (lseek(fp_src, 0, SEEK_SET) < 0) {
+		PRINT_ERR("Cannot lseek() to get the dump header from the "
 			"dump file!\n");
-                rc = -1; goto out;
-        }
-        if (read(fp_src,(char *)&s390_dh, sizeof(s390_dh)) != sizeof(s390_dh)) {
+		rc = -1; goto out;
+	}
+	if (read(fp_src,(char *)&s390_dh, sizeof(s390_dh)) != sizeof(s390_dh)) {
 		PRINT_ERR("Cannot read() dump header from dump file!\n");
-                rc = -1; goto out;
-        }
+		rc = -1; goto out;
+	}
 
-        s390sa_to_reg_header(&s390_dh,&dh);
+	s390sa_to_reg_header(&s390_dh,&dh);
 
 	if(strcmp(g.parm_dump_compress,PARM_DUMP_COMPRESS_GZIP) == 0){
 		dh.dump_compress = DUMP_COMPRESS_GZIP;
@@ -1271,17 +1253,17 @@ dump_create_s390sa(char* sourcedev, char* dumpdir)
 		dh.num_dump_pages = g.parm_dump_mem / dh.page_size;
 	}
 
-        memset(dump_page_buf, 0, DUMP_BUFFER_SIZE);
-        memcpy((void *)dump_page_buf, (const void *)&dh, sizeof(dump_header_t));
-        if(lseek(fp_dump, 0L, SEEK_SET) < 0) {
+	memset(dump_page_buf, 0, DUMP_BUFFER_SIZE);
+	memcpy((void *)dump_page_buf, (const void *)&dh, sizeof(dump_header_t));
+	if(lseek(fp_dump, 0L, SEEK_SET) < 0) {
 		PRINT_ERR("lseek() failed\n");
 		rc = -1; goto out;
 	}
-        if (dump_write(fp_dump, (char *)dump_page_buf, DUMP_BUFFER_SIZE)
+	if (dump_write(fp_dump, (char *)dump_page_buf, DUMP_BUFFER_SIZE)
 		!= DUMP_BUFFER_SIZE) {
 		PRINT_ERR("Error: Write dump header failed\n");
 		rc = -1; goto out;
-        }
+	}
 
 	/* write dump */
 
@@ -1302,38 +1284,38 @@ dump_create_s390sa(char* sourcedev, char* dumpdir)
 		/* get the new compressed page size
                  */
 
-                size = compress_fn((unsigned char *)buf, DUMP_PAGE_SIZE,
+		size = compress_fn((unsigned char *)buf, DUMP_PAGE_SIZE,
 			(unsigned char *)dpcpage, DUMP_PAGE_SIZE);
 
-                /* if compression failed or compressed was ineffective,
-                 * we write an uncompressed page
-                 */
-                if (size < 0) {
-                        dp_flags = DUMP_DH_RAW;
-                        dp_size  = DUMP_PAGE_SIZE;
-                } else {
-                        dp_flags = DUMP_DH_COMPRESSED;
-                        dp_size  = size;
-                }
-	        dp.address = mem_loc;
-                dp.size    = dp_size;
-                dp.flags   = dp_flags;
-                memcpy((void *)(dump_page_buf + buf_loc), (const void *)&dp,
+		/* if compression failed or compressed was ineffective,
+		 * we write an uncompressed page
+		 */
+		if (size < 0) {
+			dp_flags = DUMP_DH_RAW;
+			dp_size  = DUMP_PAGE_SIZE;
+		} else {
+			dp_flags = DUMP_DH_COMPRESSED;
+			dp_size  = size;
+		}
+		dp.address = mem_loc;
+		dp.size    = dp_size;
+		dp.flags   = dp_flags;
+		memcpy((void *)(dump_page_buf + buf_loc), (const void *)&dp,
 			sizeof(dump_page_t));
-                buf_loc += sizeof(dump_page_t);
+		buf_loc += sizeof(dump_page_t);
 		/* copy the page of memory */
-                if (dp_flags & DUMP_DH_COMPRESSED) {
-                        /* copy the compressed page */
-                        memcpy((void *)(dump_page_buf + buf_loc),
+		if (dp_flags & DUMP_DH_COMPRESSED) {
+			/* copy the compressed page */
+			memcpy((void *)(dump_page_buf + buf_loc),
 				(const void *)dpcpage, dp_size);
-                } else {
-                        /* copy directly from memory */
-                        memcpy((void *)(dump_page_buf + buf_loc),
+		} else {
+			/* copy directly from memory */
+			memcpy((void *)(dump_page_buf + buf_loc),
 				(const void *)buf, dp_size);
-                }
+		}
 		buf_loc += dp_size;
 		if(dump_write(fp_dump, dump_page_buf, buf_loc) != buf_loc){
-                        PRINT_ERR("write error\n");
+			PRINT_ERR("write error\n");
 			rc = -1; goto out;
 		}
 		buf_loc = 0;
@@ -1341,11 +1323,11 @@ dump_create_s390sa(char* sourcedev, char* dumpdir)
 		dump_display_progress(mem_loc, dh.memory_size);
 	}
 
-        /* write end marker */
- 
-        dp.address = 0x0;
-        dp.size    = DUMP_DH_END;
-        dp.flags   = 0x0;
+	/* write end marker */
+
+	dp.address = 0x0;
+	dp.size    = DUMP_DH_END;
+	dp.flags   = 0x0;
 	dump_write(fp_dump, dump_page_buf, sizeof(dump_page_t)); 
 out:
 	if(fp_src != -1)
