@@ -2,7 +2,7 @@
  * s390-tools/zipl/include/zipl.h
  *   zSeries Initial Program Loader tool.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2006.
  *
  * Author(s): Carsten Otte <cotte@de.ibm.com>
  *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
@@ -35,12 +35,8 @@
 #define ZIPL_CONF_VAR			"ZIPLCONF"
 #define ZIPL_DEFAULT_CONF		"/etc/zipl.conf"
 
-#define STRINGIFY_1(x)			#x
-#define STRINGIFY(x)			STRINGIFY_1(x)
-
 #define FSDUMP_IMAGE	STRINGIFY(ZFCPDUMP_DIR) "/" STRINGIFY(ZFCPDUMP_IMAGE)
 #define FSDUMP_RAMDISK	STRINGIFY(ZFCPDUMP_DIR) "/" STRINGIFY(ZFCPDUMP_RD)
-#define RELEASE_STRING	STRINGIFY(S390_TOOLS_RELEASE)
 
 /* Internal component load address type */
 typedef uint64_t address_t;
