@@ -2,7 +2,7 @@
  * s390-tools/zipl/src/bootmap.c
  *   Functions to build the bootmap file.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2006.
  *
  * Author(s): Carsten Otte <cotte@de.ibm.com>
  *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
@@ -23,6 +23,7 @@
 #include "disk.h"
 #include "error.h"
 #include "misc.h"
+#include "zt_common.h"
 
 
 /* Header text of the bootmap file */
@@ -639,12 +640,30 @@ add_segment_program(int fd, struct job_segment_data* segment,
 }
 
 
+#define DUMP_PARAM_MAX_LEN	896
+
+static char *
+create_dump_fs_parmline(const char* parmline, const char* root_dev,
+			int part_num, uint64_t mem, int max_cpus)
+{
+	char* result;
+
+	result = misc_malloc(DUMP_PARAM_MAX_LEN);
+	if (!result)
+		return NULL;
+	snprintf(result, DUMP_PARAM_MAX_LEN, "%s%sroot=%s dump_part=%d "
+		 "dump_mem=%lld maxcpus=%d", parmline ? parmline : "",
+		 parmline ? " " : "", root_dev, part_num,
+		 (unsigned long long) mem, max_cpus);
+	result[DUMP_PARAM_MAX_LEN - 1] = 0;
+	return result;
+}
+
+
 static int
 get_dump_fs_parmline(char* partition, char* parameters, uint64_t mem,
 		     char** result, struct disk_info* target_info)
 {
-	char part_param[20];
-	char mem_param[35];
 	char* buffer;
 	struct disk_info* info;
 	int rc;
@@ -656,11 +675,6 @@ get_dump_fs_parmline(char* partition, char* parameters, uint64_t mem,
 			   partition);
 		return rc;
 	}
-	/* Create scsi dump parameter */
-	snprintf(part_param, sizeof(part_param), "dump_part=%d",
-		 info->partnum);
-	snprintf(mem_param, sizeof(mem_param), "dump_mem=%lld",
-		 (unsigned long long) mem);
 	if ((info->type != disk_type_scsi) || (info->partnum == 0)) {
 		error_reason("Device '%s' is not a SCSI partition",
 			     partition);
@@ -674,14 +688,8 @@ get_dump_fs_parmline(char* partition, char* parameters, uint64_t mem,
 		return -1;
 	}
 	disk_free_info(info);
-	if (parameters != NULL) {
-		buffer = misc_malloc(strlen(parameters) + strlen(part_param) +
-				     strlen(mem_param) + 3);
-		if (buffer != NULL)
-			sprintf(buffer, "%s %s %s", parameters, part_param,
-				mem_param);
-	} else
-		buffer = misc_strdup(part_param);
+	buffer = create_dump_fs_parmline(parameters, "/dev/ram0", info->partnum,
+					 mem, 1);
 	if (buffer == NULL)
 		return -1;
 	*result = buffer;
@@ -698,24 +706,24 @@ add_dump_fs_program(int fd, struct job_dump_fs_data* dump_fs,
 	struct job_ipl_data ipl;
 	int rc;
 
-	/* Ensure that necessary files are accessible */
+	/* Convert fs dump job to IPL job */
 	rc = misc_check_readable_file(FSDUMP_IMAGE);
 	if (rc) {
 		error_text("Need external file '%s' for file system dump",
 			   FSDUMP_IMAGE);
 		return rc;
 	}
-	rc = misc_check_readable_file(FSDUMP_RAMDISK);
-	if (rc) {
-		error_text("Need external file '%s' for file system dump",
-			   FSDUMP_RAMDISK);
-		return rc;
-	}
-	/* Convert fs dump job to IPL job */
 	ipl.image = FSDUMP_IMAGE;
 	ipl.image_addr = DEFAULT_IMAGE_ADDRESS;
-	ipl.ramdisk = FSDUMP_RAMDISK;
-	ipl.ramdisk_addr = DEFAULT_RAMDISK_ADDRESS;
+
+	/* Ramdisk is no longer required with new initramfs dump system. */
+	if (misc_check_readable_file(FSDUMP_RAMDISK))
+		ipl.ramdisk = NULL;
+	else {
+		ipl.ramdisk = FSDUMP_RAMDISK;
+		ipl.ramdisk_addr = DEFAULT_RAMDISK_ADDRESS;
+	}
+
 	/* Get file system dump parmline */
 	rc = get_dump_fs_parmline(dump_fs->partition, dump_fs->parmline,
 				  dump_fs->mem, &ipl.parmline, info);
@@ -902,12 +910,40 @@ bootmap_create(struct job_data* job, disk_blockptr_t* program_table,
 		free(filename);
 		return -1;
 	}
-	/* Check for supported disk types */
+	/* Check for supported disk and driver types */
 	switch (info->type) {
 	case disk_type_scsi:
+		if (info->drv_name && (strcmp(info->drv_name, "sd") != 0)) {
+			error_reason("Unsupported device driver '%s'",
+				     info->drv_name);
+			disk_free_info(info);
+			close(fd);
+			free(filename);
+			return -1;
+		}
+		break;
 	case disk_type_fba:
 	case disk_type_eckd_classic:
 	case disk_type_eckd_compatible:
+		if (info->drv_name && (strcmp(info->drv_name, "dasd") != 0)) {
+			error_reason("Unsupported device driver '%s'",
+				     info->drv_name);
+			disk_free_info(info);
+			close(fd);
+			free(filename);
+			return -1;
+		}
+		/* Check for valid CHS geometry data. */
+		if ((info->geo.cylinders == 0) || (info->geo.heads == 0) ||
+		    (info->geo.sectors == 0)) {
+			error_reason("Invalid disk geometry (CHS=%d/%d/%d)",
+				     info->geo.cylinders, info->geo.heads,
+				     info->geo.sectors);
+			disk_free_info(info);
+			close(fd);
+			free(filename);
+			return -1;
+		}
 		break;
 	case disk_type_diag:
 	case disk_type_unknown:
