@@ -2,7 +2,7 @@
  * s390-tools/zipl/src/disk.c
  *   Functions to handle disk layout specific operations.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2006.
  *
  * Author(s): Carsten Otte <cotte@de.ibm.com>
  *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
@@ -23,7 +23,7 @@
 
 #include "error.h"
 #include "misc.h"
-#include "procpart.h"
+#include "proc.h"
 
 /* from linux/fs.h */
 #define FIBMAP			_IO(0x00,1)
@@ -66,7 +66,8 @@ int
 disk_get_info(const char* device, struct disk_info** info)
 {
 	struct stat stats;
-	struct procpart_entry entry;
+	struct proc_part_entry part_entry;
+	struct proc_dev_entry dev_entry;
 	struct dasd_information dasd_info;
 	struct disk_info *data;
 	int fd;
@@ -146,9 +147,19 @@ disk_get_info(const char* device, struct disk_info** info)
 	if (data->partnum != 0)
 		data->partition = stats.st_rdev;
 	/* Try to get device name */
-	if (procpart_get_entry(data->device, &entry) == 0) {
-		data->name = misc_strdup(entry.name);
-		procpart_free_entry(&entry);
+	if (proc_part_get_entry(data->device, &part_entry) == 0) {
+		data->name = misc_strdup(part_entry.name);
+		proc_part_free_entry(&part_entry);
+		if (data->name == NULL) {
+			close(fd);
+			free(data);
+			return -1;
+		}
+	}
+	/* Try to get device driver name */
+	if (proc_dev_get_entry(data->device, 1, &dev_entry) == 0) {
+		data->drv_name = misc_strdup(dev_entry.name);
+		proc_dev_free_entry(&dev_entry);
 		if (data->name == NULL) {
 			close(fd);
 			free(data);
@@ -210,6 +221,8 @@ disk_free_info(struct disk_info* info)
 {
 	if (info->name)
 		free(info->name);
+	if (info->drv_name)
+		free(info->drv_name);
 	free(info);
 }
 
@@ -243,7 +256,7 @@ disk_get_blocknum(int fd, blocknum_t logical, blocknum_t* physical,
 	}
 	/* Files on ReiserFS need unpacking */
 	if (buf.f_type == REISERFS_SUPER_MAGIC) {
-		if (ioctl (fd, REISERFS_IOC_UNPACK, 1) == ENOSPC) {
+		if (ioctl(fd, REISERFS_IOC_UNPACK, 1)) {
 			error_reason("Could not unpack ReiserFS file");
 			return -1;
 		}
@@ -471,6 +484,10 @@ disk_print_info(struct disk_info* info)
 		printf("  Device name.....................: %s\n",
 		       info->name);
 	}
+	if (info->drv_name) {
+		printf("  Device driver name..............: %s\n",
+		       info->drv_name);
+	}
 	if ((info->type == disk_type_fba) ||
 	    (info->type == disk_type_diag) ||
 	    (info->type == disk_type_eckd_classic) ||
