@@ -2,7 +2,7 @@
  * s390-tools/zipl/src/install.c
  *   Functions handling the installation of the boot loader code onto disk.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2006.
  *
  * Author(s): Carsten Otte <cotte@de.ibm.com>
  *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
@@ -291,8 +291,10 @@ install_bootloader(const char* device, disk_blockptr_t *program_table,
 		printf(".\n");
 	} else if (info->devno >= 0) {
 		printf("%04x.\n", info->devno);
-	} else
+	} else {
 		disk_print_devt(info->device);
+		printf(".\n");
+	}
 	/* Open device file */
 	fd = open(device, O_RDWR);
 	if (fd == -1) {
