@@ -3,7 +3,7 @@
  *   Functions and data structures representing the actual 'job' that the
  *   user wants us to execute.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2006.
  *
  * Author(s): Carsten Otte <cotte@de.ibm.com>
  *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
@@ -90,8 +90,6 @@ get_command_line(int argc, char* argv[], struct command_line* line)
 
 	memset((void *) &cmdline, 0, sizeof(struct command_line));
 	cmdline.type = section_invalid;
-	/* Turn off standard option parser errors - we have our own */
-	opterr = 0;
 	is_keyword = 0;
 	/* Process options */
 	do {
@@ -188,31 +186,10 @@ get_command_line(int argc, char* argv[], struct command_line* line)
 		case -1:
 			/* End of options string */
 			break;
-		case '?':
-			/* Unrecognized option */
-			if (optopt != 0) {
-				if ((optopt != ':') &&
-				    (strchr(option_string, optopt) != NULL)) {
-					for (i=0;
-					     (options[i].val != 0) &&
-					     (options[i].val != optopt);
-					     i++);
-				    error_reason("Option '%s' requires an "
-				    		 "argument", options[i].name);
-				} else
-					error_reason("Unrecognized option -%c",
-						     optopt);
-			} else if (optind > 1) {
-				error_reason("Unrecognized option '%s'",
-					     argv[optind - 1]);
-			}
-			else
-				error_reason("Unrecognized option");
-			rc = -1;
-			break;
 		default:
-			error_reason("Internal error of command line parser");
-			rc = -1;
+			fprintf(stderr, "Try 'zipl --help' for "
+					"more information.\n");
+			exit(1);
 		}
 		if (rc)
 			return rc;
