@@ -2,7 +2,7 @@
  * s390-tools/zipl/src/zipl.c
  *   zSeries Initial Program Loader tool.
  *
- * Copyright (C) 2001-2003 IBM Deutschland Entwicklung GmbH, IBM Corporation
+ * Copyright IBM Corp. 2001, 2006.
  *
  * Author(s): Carsten Otte <cotte@de.ibm.com>
  *            Peter Oberparleiter <Peter.Oberparleiter@de.ibm.com>
@@ -25,6 +25,7 @@
 #include "install.h"
 #include "job.h"
 #include "misc.h"
+#include "zt_common.h"
 
 
 /* Flag deciding the level of verbosity */
@@ -37,15 +38,10 @@ int interactive = 1;
 int dry_run = 1;
 
 /* Full tool name */
-static const char tool_name[] = "zSeries Initial Program Loader";
+static const char tool_name[] = "zipl: zSeries Initial Program Loader";
 
 /* Copyright notice */
-static const char copyright_notice[] = "Copyright (C) 2001-2003 "
-				       "IBM Deutschland Entwicklung GmbH, "
-				       "IBM Corporation";
-
-/* Contact information for bug reporting */
-static const char contact_information[] = "linux390@de.ibm.com";
+static const char copyright_notice[] = "Copyright IBM Corp. 2001, 2006";
 
 /* Usage information */
 static const char* usage_text[] = {
@@ -73,8 +69,7 @@ static const char* usage_text[] = {
 "-n, --noninteractive            Answer all confirmation questions with 'yes'",
 "-V, --verbose                   Provide more verbose output",
 "-a, --add-files                 Add all referenced files to bootmap file",
-"    --dry-run                   Simulate run but don't modify IPL records",
-""
+"    --dry-run                   Simulate run but don't modify IPL records"
 };
 
 
@@ -86,7 +81,6 @@ print_usage(void)
 
 	for (i=0; i < sizeof(usage_text) / sizeof(usage_text[0]); i++)
 		printf("%s\n", usage_text[i]);
-	printf("Please report bugs to: %s\n", contact_information);
 }
 
 
